version 8
clear
set matsize 180
set logtype text
set mem 800m
set more off
adopath + "brazdspl/%stata/ado"

cd "$root"

* obtain from RAIS, not PIA: ln_empl labf_wh_tot 

capture log close
log using "brazempl/logs/xtreg-wrkrfrmfe-reg.log", replace


/* RAIS REGRESSIONS */
/*------------------*/

use "brazempl/data/firms-niv50", replace
keep firmid niv50 indconfl
duplicates drop
foreach yr in 90 97 {
  gen byte niv50_`yr' = niv50
  }
drop niv50
reshape long niv50_, i(firmid) j(year)
rename niv50_ niv50
preserve
foreach yr in 90 97 {
  tempfile firms`yr'
  restore, preserve
  keep if year == `yr'
  sort firmid year
  compress
  save `firms`yr''
  }
restore

* use firm information from Manufacturing estimates, then fill in from Agriculture, Commerce, Services
foreach yr in 90 97 {
  tempfile frminf`yr'
  use `firms`yr'', clear
  foreach sec in 4 1 2 5 {
    sort firmid 
    merge firmid using "brazempl/est/v1/firmpred-edu-sec`sec'-`yr'"
    drop _m
    }
  sort firmid
  merge firmid using "brazempl/data/firm-skills-`yr'", nokeep
  drop _m
  sort firmid year
  compress
  save `frminf`yr''
  }
local yr 90
use `frminf`yr'', clear
foreach yr in 97 {
  append using `frminf`yr''
  }
label var xbfirm "Avg. Predicted Wage (in plant & firm)"
label var avgpsihat "Avg. Establishment Effect (in firm)"
label var labf_skil_tot "Share Engin'rs, Tech's, Managers"
*YR forvalues yr = 90/98 {
foreach yr in 90 97 {
  gen byte indyr`yr' = (year==`yr')
  label var indyr`yr' "Year 19`yr'"
  } 
drop indyr90

summ indconfl
count if indconfl==1

* merge sector information 
sort niv50 year
merge niv50 year using "brazaux/auxil/seclvl", nokeep
label var realexch "Real.Exch.Rate: E*USD/P"
label var fdistk "FDI Stock (Billion USD)"
tab niv50
* tab niv50, nolab

*YR
keep if year==90 | year==97
sort firmid year
iis niv50
tis year

xtreg avgxbhat avgpsihat herfsale reffpen tarfoutp tarfintm fdistk realexch ln_empl labf_wh_tot labf_skil_tot, fe
*YR est2vec wrkrfrmfe_rais, replace e(r2 r2_a r2_w r2_o r2_b mss tss corr sigma_u sigma_e df_r df_m) name(rais_avgxbhat) var(avgxbhat avgpsihat herfsale reffpen tarfoutp tarfintm fdistk realexch ln_empl ln_cap labf_wh_tot labf_skil_tot kappa mu lnlp ln_sales_empl profit_cap lntfp indyr90 indyr92 indyr93 indyr94 indyr95 indyr96 indyr97 indyr98)
est2vec wrkrfrmfe_rais, replace e(r2 r2_a r2_w r2_o r2_b mss tss corr sigma_u sigma_e df_r df_m) name(rais_avgxbhat) var(avgxbhat avgpsihat herfsale reffpen tarfoutp tarfintm fdistk realexch ln_empl ln_cap labf_wh_tot labf_skil_tot kappa mu lnlp ln_sales_empl profit_cap lntfp indyr90 indyr97)
test herfsale = reffpen = tarfoutp = tarfintm = fdistk = 0
est2vec wrkrfrmfe_rais, replace r(F df df_r p) name(rais_avgxbhat)

xtreg avgpsihat avgxbhat herfsale reffpen tarfoutp tarfintm fdistk realexch ln_empl labf_wh_tot labf_skil_tot, fe
est2vec wrkrfrmfe_rais, addto(wrkrfrmfe_rais) name(rais_avgpsihat)
test herfsale = reffpen = tarfoutp = tarfintm = fdistk = 0
est2vec wrkrfrmfe_rais, raddto(wrkrfrmfe_rais) name(rais_avgpsihat)

*YR xtreg avgxbhat avgpsihat herfsale reffpen tarfoutp tarfintm fdistk ln_empl labf_wh_tot labf_skil_tot indyr91-indyr98, fe
xtreg avgxbhat avgpsihat herfsale reffpen tarfoutp tarfintm fdistk ln_empl labf_wh_tot labf_skil_tot indyr97, fe
est2vec wrkrfrmfe_rais, addto(wrkrfrmfe_rais) name(rais_avgxbhat_indyr)
test herfsale = reffpen = tarfoutp = tarfintm = fdistk = 0
est2vec wrkrfrmfe_rais, raddto(wrkrfrmfe_rais) name(rais_avgxbhat_indyr)

*YR xtreg avgpsihat avgxbhat herfsale reffpen tarfoutp tarfintm fdistk ln_empl labf_wh_tot labf_skil_tot indyr91-indyr98, fe
xtreg avgpsihat avgxbhat herfsale reffpen tarfoutp tarfintm fdistk ln_empl labf_wh_tot labf_skil_tot indyr97, fe
est2vec wrkrfrmfe_rais, addto(wrkrfrmfe_rais) name(rais_avgpsihat_indyr)
test herfsale = reffpen = tarfoutp = tarfintm = fdistk = 0
est2vec wrkrfrmfe_rais, raddto(wrkrfrmfe_rais) name(rais_avgpsihat_indyr)

*YR reg avgxbhat avgpsihat herfsale reffpen tarfoutp tarfintm fdistk ln_empl labf_wh_tot labf_skil_tot indyr91-indyr98, cluster(niv50)
reg avgxbhat avgpsihat herfsale reffpen tarfoutp tarfintm fdistk ln_empl labf_wh_tot labf_skil_tot indyr97, cluster(niv50)
est2vec wrkrfrmfe_rais, addto(wrkrfrmfe_rais) name(rais_avgxbhat_indyr_nosecfe)
test herfsale = reffpen = tarfoutp = tarfintm = fdistk = 0
est2vec wrkrfrmfe_rais, raddto(wrkrfrmfe_rais) name(rais_avgxbhat_indyr_nosecfe)

*YR reg avgpsihat avgxbhat herfsale reffpen tarfoutp tarfintm fdistk ln_empl labf_wh_tot labf_skil_tot indyr91-indyr98, cluster(niv50)
reg avgpsihat avgxbhat herfsale reffpen tarfoutp tarfintm fdistk ln_empl labf_wh_tot labf_skil_tot indyr97, cluster(niv50)
est2vec wrkrfrmfe_rais, addto(wrkrfrmfe_rais) name(rais_avgpsihat_indyr_nosecfe)
test herfsale = reffpen = tarfoutp = tarfintm = fdistk = 0
est2vec wrkrfrmfe_rais, raddto(wrkrfrmfe_rais) name(rais_avgpsihat_indyr_nosecfe)

*YR xtreg avgxbhat avgpsihat ln_empl labf_wh_tot labf_skil_tot indyr91-indyr98, fe
xtreg avgxbhat avgpsihat ln_empl labf_wh_tot labf_skil_tot indyr97, fe
est2vec wrkrfrmfe_rais, addto(wrkrfrmfe_rais) name(rais_avgxbhat_indyr_v2)
test 0 = 0
est2vec wrkrfrmfe_rais, raddto(wrkrfrmfe_rais) name(rais_avgxbhat_indyr_v2)

*YR xtreg avgxbhat avgpsihat herfsale tarfintm fdistk ln_empl labf_wh_tot labf_skil_tot indyr91-indyr98, fe
xtreg avgxbhat avgpsihat herfsale tarfintm fdistk ln_empl labf_wh_tot labf_skil_tot indyr97, fe
est2vec wrkrfrmfe_rais, addto(wrkrfrmfe_rais) name(rais_avgxbhat_indyr_v3)
test herfsale = tarfintm = fdistk = 0
est2vec wrkrfrmfe_rais, raddto(wrkrfrmfe_rais) name(rais_avgxbhat_indyr_v3)

*YR xtreg avgxbhat avgpsihat herfsale tarfoutp tarfintm fdistk ln_empl labf_wh_tot labf_skil_tot indyr91-indyr98, fe
xtreg avgxbhat avgpsihat herfsale tarfoutp tarfintm fdistk ln_empl labf_wh_tot labf_skil_tot indyr97, fe
est2vec wrkrfrmfe_rais, addto(wrkrfrmfe_rais) name(rais_avgxbhat_indyr_v4)
test herfsale = tarfoutp = tarfintm = fdistk = 0
est2vec wrkrfrmfe_rais, raddto(wrkrfrmfe_rais) name(rais_avgxbhat_indyr_v4)

est2rowlbl *, addto(wrkrfrmfe_rais) replace dropall saving path(brazempl/tex/v1/sec)
est2tex wrkrfrmfe_rais, replace dropall preserve mark(it) digits(4) fancy path(brazempl/tex/v1/sec)


/* PIA REGRESSIONS */
/*-----------------*/

local yr 90
use "brazempl/use-firms-`yr'", clear
gen byte year = `yr'
label var year "Calendar year"
*YR foreach yr in 92 93 94 95 96 97 98 {
foreach yr in 97 {
  append using "brazempl/use-firms-`yr'"
  replace year = `yr' if year==.
  }
tab niv50
* tab niv50, nolab
order firmgrp year
sort firmgrp year
iis niv50
tis year
*YR foreach yr in 90 92 93 94 95 96 97 98 {
foreach yr in 90 97 {
  gen byte indyr`yr' = (year==`yr')
  label var indyr`yr' "Year 19`yr'"
  } 
drop indyr90
keep firmgrp year niv50 avgxbhat avgpsihat ln_sales_empl profit_cap ln_empl ln_cap ln_cap_empl labf_wh_tot labf_skil_tot lntfp lnlp kappa mu indyr*
order firmgrp year niv50
sort niv50 year
merge niv50 year using "brazaux/auxil/seclvl", nokeep
label var realexch "Real.Exch.Rate: E*USD/P"
label var fdistk "FDI Stock (Billion USD)"
tab niv50
* tab niv50, nolab

keep if year==90 | year==97
sort firmgrp year
iis niv50
tis year

xtreg avgxbhat avgpsihat herfsale reffpen tarfoutp tarfintm fdistk realexch ln_empl ln_cap labf_wh_tot labf_skil_tot kappa mu lnlp ln_sales_empl profit_cap lntfp, fe
*YR est2vec wrkrfrmfe_pia, replace e(r2 r2_a r2_w r2_o r2_b mss tss corr sigma_u sigma_e df_r df_m) name(avgxbhat) var(avgxbhat avgpsihat herfsale reffpen tarfoutp tarfintm fdistk realexch ln_empl ln_cap labf_wh_tot labf_skil_tot kappa mu lnlp ln_sales_empl profit_cap lntfp indyr90 indyr92 indyr93 indyr94 indyr95 indyr96 indyr97 indyr98)
est2vec wrkrfrmfe_pia, replace e(r2 r2_a r2_w r2_o r2_b mss tss corr sigma_u sigma_e df_r df_m) name(avgxbhat) var(avgxbhat avgpsihat herfsale reffpen tarfoutp tarfintm fdistk realexch ln_empl ln_cap labf_wh_tot labf_skil_tot kappa mu lnlp ln_sales_empl profit_cap lntfp indyr90 indyr97)
test herfsale = reffpen = tarfoutp = tarfintm = fdistk = 0
est2vec wrkrfrmfe_pia, replace r(F df df_r p) name(avgxbhat)

xtreg avgpsihat avgxbhat herfsale reffpen tarfoutp tarfintm fdistk realexch ln_empl ln_cap labf_wh_tot labf_skil_tot kappa mu lnlp ln_sales_empl profit_cap lntfp, fe
est2vec wrkrfrmfe_pia, addto(wrkrfrmfe_pia) name(avgpsihat)
test herfsale = reffpen = tarfoutp = tarfintm = fdistk = 0
est2vec wrkrfrmfe_pia, raddto(wrkrfrmfe_pia) name(avgpsihat)

*YR xtreg avgxbhat avgpsihat herfsale reffpen tarfoutp tarfintm fdistk ln_empl ln_cap labf_wh_tot labf_skil_tot kappa mu lnlp ln_sales_empl profit_cap lntfp indyr92-indyr98, fe
xtreg avgxbhat avgpsihat herfsale reffpen tarfoutp tarfintm fdistk ln_empl ln_cap labf_wh_tot labf_skil_tot kappa mu lnlp ln_sales_empl profit_cap lntfp indyr97, fe
est2vec wrkrfrmfe_pia, addto(wrkrfrmfe_pia) name(avgxbhat_indyr)
test herfsale = reffpen = tarfoutp = tarfintm = fdistk = 0
est2vec wrkrfrmfe_pia, raddto(wrkrfrmfe_pia) name(avgxbhat_indyr)

*YR xtreg avgpsihat avgxbhat herfsale reffpen tarfoutp tarfintm fdistk ln_empl ln_cap labf_wh_tot labf_skil_tot kappa mu lnlp ln_sales_empl profit_cap lntfp indyr92-indyr98, fe
xtreg avgpsihat avgxbhat herfsale reffpen tarfoutp tarfintm fdistk ln_empl ln_cap labf_wh_tot labf_skil_tot kappa mu lnlp ln_sales_empl profit_cap lntfp indyr97, fe
est2vec wrkrfrmfe_pia, addto(wrkrfrmfe_pia) name(avgpsihat_indyr)
test herfsale = reffpen = tarfoutp = tarfintm = fdistk = 0
est2vec wrkrfrmfe_pia, raddto(wrkrfrmfe_pia) name(avgpsihat_indyr)

*YR reg avgxbhat avgpsihat herfsale reffpen tarfoutp tarfintm fdistk ln_empl ln_cap labf_wh_tot labf_skil_tot kappa mu lnlp ln_sales_empl profit_cap lntfp indyr92-indyr98, cluster(niv50)
reg avgxbhat avgpsihat herfsale reffpen tarfoutp tarfintm fdistk ln_empl ln_cap labf_wh_tot labf_skil_tot kappa mu lnlp ln_sales_empl profit_cap lntfp indyr97, cluster(niv50)
est2vec wrkrfrmfe_pia, addto(wrkrfrmfe_pia) name(avgxbhat_indyr_nosecfe)
test herfsale = reffpen = tarfoutp = tarfintm = fdistk = 0
est2vec wrkrfrmfe_pia, raddto(wrkrfrmfe_pia) name(avgxbhat_indyr_nosecfe)

*YR reg avgpsihat avgxbhat herfsale reffpen tarfoutp tarfintm fdistk ln_empl ln_cap labf_wh_tot labf_skil_tot kappa mu lnlp ln_sales_empl profit_cap lntfp indyr92-indyr98, cluster(niv50)
reg avgpsihat avgxbhat herfsale reffpen tarfoutp tarfintm fdistk ln_empl ln_cap labf_wh_tot labf_skil_tot kappa mu lnlp ln_sales_empl profit_cap lntfp indyr97, cluster(niv50)
est2vec wrkrfrmfe_pia, addto(wrkrfrmfe_pia) name(avgpsihat_indyr_nosecfe)
test herfsale = reffpen = tarfoutp = tarfintm = fdistk = 0
est2vec wrkrfrmfe_pia, raddto(wrkrfrmfe_pia) name(avgpsihat_indyr_nosecfe)

est2tex wrkrfrmfe_pia, replace dropall preserve mark(it) digits(4) fancy path(brazempl/tex/v1/sec)

local i = 0
foreach var in herfsale reffpen tarfoutp tarfintm fdistk realexch {
  local i = `i' + 1
  local othrvar = subinstr("fdistk reffpen tarfoutp tarfintm herfsale realexch","`var'","",.)
  xtreg `var' ln_sales_empl profit_cap ln_cap lntfp lnlp kappa mu avgxbhat avgpsihat ln_empl labf_wh_tot labf_skil_tot `othrvar', fe
  if `i' == 1 {
    est2vec omtchk_pia, replace e(r2 r2_a r2_w r2_o r2_b mss tss corr sigma_u sigma_e df_r df_m) name(`var') var(avgxbhat avgpsihat ln_sales_empl profit_cap ln_empl ln_cap labf_wh_tot labf_skil_tot lntfp lnlp kappa mu realexch fdistk reffpen tarfoutp tarfintm herfsale)
    }
  else {
    est2vec omtchk_pia, addto(omtchk_pia) name(`var')
    }
  }

est2tex omtchk_pia, replace dropall preserve mark(it) digits(3) fancy path(brazempl/tex/v1/sec)
  
log close
cd "$home"
