local refyr = 90
local refsec = 4

version 8
set matsize 120
set more off
adopath + "brazdspl/%stata/ado"

cd "$root"

gprefs set custom2 pen1_thick 1
gprefs set custom2 pen2_thick 1
gprefs set custom2 pen3_thick 1
gprefs set custom2 pen4_thick 1
gprefs set custom2 pen5_thick 1
gprefs set custom2 pen6_thick 1
gprefs set custom2 pen7_thick 1
gprefs set custom2 pen8_thick 1
gprefs set custom2 pen1_color 0 0 0     /* black  */
gprefs set custom2 pen2_color 155 0 0   /* red    */
gprefs set custom2 pen3_color 0 128 190 /* blue   */
gprefs set custom2 pen4_color 0 140 65  /* green  */
gprefs set custom2 pen5_color 220 50 25 /* red    */
gprefs set custom2 pen6_color 128 0 128 /* purple */
gprefs set custom2 pen7_color 0 80 0    /* green  */
gprefs set custom2 pen8_color 80 80 80  /* gray   */
gprefs set window displaythick on

* gprefs set window scheme custom2
gprefs set window scheme monochrome
* translator set gph2eps scheme custom2
translator set gph2eps scheme monochrome

capture program drop dropmiss
program define dropmiss
    syntax [varlist]
    local nvar : word count `varlist'
    foreach var of local varlist {
      capture drop if `var'==.
      }
end


/* AKMT estimates and summary statistics */

local yr = `refyr'
local sec = `refsec'
insheet using "brazempl/auxil/akmt-worker-plantfe.csv", comma names clear
replace _rowname=lower(_rowname)
replace _rowname=subinstr(_rowname," ","",.)
keep _rowname fr92coeff us90bcoeff
dropmiss
preserve
    drop if substr(_rowname,1,3)=="pot" | substr(_rowname,1,7)=="fem_pot"
    save "brazempl/auxil/akmtb", replace
    drop _all
    matload akmtb, path(brazempl/auxil) over
restore, preserve
    keep if substr(_rowname,1,3)=="pot" | substr(_rowname,1,7)=="fem_pot"
    save "brazempl/auxil/akmtpotx", replace
    drop _all
    matload akmtpotx, path(brazempl/auxil) over
restore
insheet using "brazempl/auxil/akmt-summdata.csv", comma names clear
keep _rowname fr92mean us90mean
replace _rowname=lower(_rowname)
replace _rowname=subinstr(_rowname," ","",.)
drop if _rowname=="ln_wage" | _rowname=="indmetro" | _rowname=="fem_indmetro" | _rowname=="indposgr" | _rowname=="fem_indposgr" | _rowname=="fem_indmetro" | _rowname=="indnoskl" | _rowname=="fem_indnoskl"
dropmiss
    drop if substr(_rowname,1,3)=="pot" | substr(_rowname,1,7)=="fem_pot"
    save "brazempl/auxil/akmtmean", replace
    drop _all
    matload akmtmean, path(brazempl/auxil) over
mat _xbfrmasc = akmtb[1..8,1] '  * akmtmean[1..8,1]
mat _xbfrfemi = akmtb[1..17,1] ' * akmtmean[1..17,1]
mat _xbusmasc = akmtb[1..8,2] '  * akmtmean[1..8,2]
mat _xbusfemi = akmtb[1..17,2] ' * akmtmean[1..17,2]
mat drop akmtb akmtmean
mat _xbmasc = _xbfrmasc , _xbusmasc
mat _xbfemi = _xbfrfemi , _xbusfemi
mat drop _xbfrmasc _xbfrfemi _xbusmasc _xbusfemi
matname _xbmasc xbhatmasc, rows(1) explicit
matname _xbfemi xbhatfemi, rows(1) explicit
mat comp = akmtpotx \ _xbmasc
mat comp = comp \ _xbfemi
mat drop _xbmasc _xbfemi
mat comp = comp \ J(1,2,-999)
insheet using "brazempl/auxil/fr92edu.csv", comma names clear
keep _rowname mean
keep if _rowname == "psihat"
mat comp[11,1] = mean[1]
insheet using "brazempl/auxil/us90edu.csv", comma names clear
keep _rowname mean
keep if _rowname == "psihat"
mat comp[11,2] = mean[1]
matname comp psihat, rows(11) explicit


/* Brazil 1990 through 1998, all sectors */

* matload cntfemtot, path(rais-sp/rais) over dropall
* matload cntmasctot, path(rais-sp/rais) over dropall

/* use regression results w/ education indicators */
*YR forvalues yr = 90/98 {
foreach yr in 90 97 {
foreach sec in 1 2 4 5 {
* Potential Experience
use "brazempl/tex/v1/wage/wage`yr'sec`sec'_tbl", clear
keep _rowname yr`yr'sec`sec'edu  /* regression results w/ education indicators */
drop if substr(_rowname,-6,7)=="schlg" | substr(_rowname,-4,4)=="_alt" | substr(_rowname,-6,6)=="unsklb"
drop if _rowname=="_se"
keep if substr(_rowname,1,5)=="potex" | substr(_rowname,1,4)=="potx" | substr(_rowname,5,5)=="potex" | substr(_rowname,5,4)=="potx"
save "brazempl/est/v1/br`yr'sec`sec'_potx", replace
drop _all
matload br`yr'sec`sec'_potx, path(brazempl/est/v1) over
erase brazempl\est\v1\br`yr'sec`sec'_potx.dta
use "brazempl/tex/v1/corr/corr`yr'sec`sec'edu_tbl", clear
keep _rowname mean
keep if _rowname=="xbhat" | _rowname=="psihat"
save "brazempl/est/v1/br`yr'sec`sec'_meanx", replace
drop _all
matload br`yr'sec`sec'_meanx, path(brazempl/est/v1) over
erase brazempl\est\v1\br`yr'sec`sec'_meanx.dta
* Other variables than potential experience
tempfile summtex
use "brazempl/tex/v1/summ/summtex`yr'sec`sec'_tbl", clear
keep _rowname mean
compress
sort _rowname
save `summtex'
use "brazempl/tex/v1/wage/wage`yr'sec`sec'_tbl", clear
keep _rowname yr`yr'sec`sec'edu
drop if substr(_rowname,-6,7)=="schlg" | substr(_rowname,-4,4)=="_alt" | substr(_rowname,-6,6)=="unsklb"
drop if _rowname=="_se"
drop if substr(_rowname,1,5)=="potex" | substr(_rowname,1,4)=="potx" | substr(_rowname,5,5)=="potex" | substr(_rowname,5,4)=="potx"
* drop if yr`yr'sec`sec'edu == -999 | substr(_rowname,1,2)=="e("
/* following line depends on use of education regression results */
keep if substr(_rowname,-4,4) == "prof" | substr(_rowname,-4,4) == "tech" | substr(_rowname,-4,4)=="whit" | substr(_rowname,-4,4)=="sklb" | substr(_rowname,-4,4)=="prim" | substr(_rowname,-4,4)=="high" | substr(_rowname,-4,4)=="coll" | substr(_rowname,-4,4)=="grad" | substr(_rowname,-4,4)=="dfem" | substr(_rowname,-4,4)=="cons"
gen _count = _n
sort _rowname
merge _rowname using "`summtex'", nokeep
drop _m
sort _count
drop _count
save "brazempl/est/v1/mmr`yr'sec`sec'", replace
drop _all
matload mmr`yr'sec`sec', path(brazempl/est/v1) over
local rownum = rowsof(mmr`yr'sec`sec')
forvalues i = 1/`rownum' {
 forvalues j = 1/2 {
  if mmr`yr'sec`sec'[`i',`j'] == -999 {
    mat mmr`yr'sec`sec'[`i',`j'] = 0
    }
   }
  }
* Multiply point estimate by sample mean (multiplication by mean zero when point estimate missing)
mat _xbbrmasc`yr'sec`sec' = mmr`yr'sec`sec'[1..8,1] '  * mmr`yr'sec`sec'[1..8,2]
mat _xbbrfemi`yr'sec`sec' = mmr`yr'sec`sec'[1..17,1] ' * mmr`yr'sec`sec'[1..17,2]
mat drop mmr`yr'sec`sec'
}
}

local rownames : rownames comp
foreach sec in 1 2 4 5 {
mat _brcomp`sec' = br90sec`sec'_potx , br97sec`sec'_potx
mat drop br90sec`sec'_potx br97sec`sec'_potx
mat _xbbrmasc`sec' = _xbbrmasc90sec`sec' , _xbbrmasc97sec`sec'
mat _xbbrfemi`sec' = _xbbrfemi90sec`sec' , _xbbrfemi97sec`sec'
mat drop _xbbrmasc90sec`sec' _xbbrmasc97sec`sec' _xbbrfemi90sec`sec' _xbbrfemi97sec`sec'
mat _brpsihat`sec' = br90sec`sec'_meanx[2,1] , br97sec`sec'_meanx[2,1]
mat drop br90sec`sec'_meanx br97sec`sec'_meanx
mat _brcomp`sec' = _brcomp`sec' \ _xbbrmasc`sec'
mat _brcomp`sec' = _brcomp`sec' \ _xbbrfemi`sec'
mat _brcomp`sec' = _brcomp`sec' \ _brpsihat`sec'
mat drop _xbbrmasc`sec' _xbbrfemi`sec' _brpsihat`sec'
matname _brcomp`sec' `rownames', rows(1..11) explicit
}

local sec 4
mat comp_tbl = _brcomp`sec' , comp
mat drop comp akmtpotx
est2tex comp, replace dropall preserve ready digits(4) fancy path(brazempl/tex/v1/tables)

mat brazpotx_tbl = _brcomp1 , _brcomp2 , _brcomp4 , _brcomp5
est2tex brazpotx, replace dropall preserve ready digits(4) fancy path(brazempl/tex/v1/tables)


/* Data set for graphing: Brazil, France, US */

local yr = `refyr'
local sec = `refsec'
mat _expprof = J(61,1,1)
drop _all
svmat _expprof
mat drop _expprof
gen potexper = _n-1
* gen potexper = _n
label var potexper "Potential Labor Force Experience"
gen potxper2 = potexper*potexper
label var potxper2 "Quadratic Experience Term"
gen potxper3 = potxper2*potexper
label var potxper3 "Cubic Experience Term"
gen potxper4 = potxper3*potexper
label var potxper4 "Quartic Experience Term"
drop _expprof1
local i = 0
foreach var in br90sec4 br97sec4 fr92 us90b {
    local i = `i' + 1
    gen `var'_masc = exp( comp_tbl[1,`i'] * potexper + comp_tbl[2,`i'] * potxper2 + comp_tbl[3,`i'] * potxper3 + comp_tbl[4,`i'] * potxper4 + comp_tbl[9,`i'] + comp_tbl[11,`i'] )
    gen `var'_femi = exp( ln(`var'_masc) + comp_tbl[5,`i'] * potexper + comp_tbl[6,`i'] * potxper2 + comp_tbl[7,`i'] * potxper3 + comp_tbl[8,`i'] * potxper4 + comp_tbl[10,`i'] )
*    gen `var'_masc = comp_tbl[1,`i'] * potexper + comp_tbl[2,`i'] * potxper2 + comp_tbl[3,`i'] * potxper3 + comp_tbl[4,`i'] * potxper4 + comp_tbl[9,`i'] + comp_tbl[11,`i']
*    gen `var'_femi = `var'_masc + comp_tbl[5,`i'] * potexper + comp_tbl[6,`i'] * potxper2 + comp_tbl[7,`i'] * potxper3 + comp_tbl[8,`i'] * potxper4 + comp_tbl[10,`i']
*    gen `var'_masc = comp_tbl[1,`i'] * potexper + comp_tbl[2,`i'] * potxper2 + comp_tbl[3,`i'] * potxper3 + comp_tbl[4,`i'] * potxper4
*    gen `var'_femi = comp_tbl[5,`i'] * potexper + comp_tbl[6,`i'] * potxper2 + comp_tbl[7,`i'] * potxper3 + comp_tbl[8,`i'] * potxper4 + `var'_masc
    }
foreach gender in masc femi {
    label var br90sec4_`gender' "Brazil 1990"
    label var br97sec4_`gender' "Brazil 1997"
    label var fr92_`gender' "France 1992"
    label var us90b_`gender' "USA 1990"
    }
drop potxper2 potxper3 potxper4
foreach var in br90sec4 br97sec4 fr92 us90b {
  foreach gender in masc femi {
    replace `var'_`gender' = `var'_`gender'/`var'_`gender'[1] if _n>1
    replace `var'_`gender' = 1 in 1
  }
 }


/* Graphs Brazil, France, US: Maximum value of Experience in 1990: 38.5 */
keep if potexper <= 30
foreach gender in masc femi {
    graph7 br90sec4_`gender' br97sec4_`gender' fr92_`gender' us90b_`gender' potexper, ylab(1(.5)3.5) ytick(1(.25)3.5) xtick(0(2)30) xlab(0(4)24,30) connect(llll) l2title("Annual Wage Rate relative to starting value") saving("brazempl/tex/v1/graphs/potx`gender'", replace)
    translate "brazempl/tex/v1/graphs/potx`gender'.gph" "brazempl/tex/v1/graphs/potx`gender'.eps", translator(gph2eps) replace
    more
    }


/* Data set for graphing: Sectors within Brazil */

mat _expprof = J(61,1,1)
drop _all
svmat _expprof
mat drop _expprof
gen potexper = _n-1
* gen potexper = _n
label var potexper "Potential Labor Force Experience"
gen potxper2 = potexper*potexper
label var potxper2 "Quadratic Experience Term"
gen potxper3 = potxper2*potexper
label var potxper3 "Cubic Experience Term"
gen potxper4 = potxper3*potexper
label var potxper4 "Quartic Experience Term"
drop _expprof1
local i = 0
foreach var in br90sec1 br97sec1 br90sec2 br97sec2 br90sec4 br97sec4 br90sec5 br97sec5 {
    local i = `i' + 1
    gen `var'_masc = exp( brazpotx_tbl[1,`i'] * potexper + brazpotx_tbl[2,`i'] * potxper2 + brazpotx_tbl[3,`i'] * potxper3 + brazpotx_tbl[4,`i'] * potxper4 + brazpotx_tbl[9,`i'] + brazpotx_tbl[11,`i'] )
    gen `var'_femi = exp( ln(`var'_masc) + brazpotx_tbl[5,`i'] * potexper + brazpotx_tbl[6,`i'] * potxper2 + brazpotx_tbl[7,`i'] * potxper3 + brazpotx_tbl[8,`i'] * potxper4 + brazpotx_tbl[10,`i'] )
*    gen `var'_masc = brazpotx_tbl[1,`i'] * potexper + brazpotx_tbl[2,`i'] * potxper2 + brazpotx_tbl[3,`i'] * potxper3 + brazpotx_tbl[4,`i'] * potxper4 + brazpotx_tbl[9,`i'] + brazpotx_tbl[11,`i']
*    gen `var'_femi = `var'_masc + brazpotx_tbl[5,`i'] * potexper + brazpotx_tbl[6,`i'] * potxper2 + brazpotx_tbl[7,`i'] * potxper3 + brazpotx_tbl[8,`i'] * potxper4 + brazpotx_tbl[10,`i']
*    gen `var'_masc = brazpotx_tbl[1,`i'] * potexper + brazpotx_tbl[2,`i'] * potxper2 + brazpotx_tbl[3,`i'] * potxper3 + brazpotx_tbl[4,`i'] * potxper4
*    gen `var'_femi = brazpotx_tbl[5,`i'] * potexper + brazpotx_tbl[6,`i'] * potxper2 + brazpotx_tbl[7,`i'] * potxper3 + brazpotx_tbl[8,`i'] * potxper4 + `var'_masc
    }
foreach gender in masc femi {
  foreach yr in 90 97 {
    label var br`yr'sec1_`gender' "Agriculture 19`yr'"
    label var br`yr'sec2_`gender' "Commerce 19`yr'"
    label var br`yr'sec4_`gender' "Manufacturing 19`yr'"
    label var br`yr'sec5_`gender' "Services 19`yr'"
    }
  }
drop potxper2 potxper3 potxper4
foreach var in br90sec1 br97sec1 br90sec2 br97sec2 br90sec4 br97sec4 br90sec5 br97sec5 {
  foreach gender in masc femi {
    replace `var'_`gender' = `var'_`gender'/`var'_`gender'[1] if _n>1
    replace `var'_`gender' = 1 in 1
  }
 }

/* Graphs Sectors in Brazil 1990, 1997: Maximum value of Experience in 1990: 38.5 */
keep if potexper <= 30
foreach gender in masc femi {
  foreach yr in 90 97 {
    graph7 br`yr'sec4_`gender' br`yr'sec5_`gender' br`yr'sec2_`gender' br`yr'sec1_`gender' potexper, ylab(1(.5)3.5) ytick(1(.25)3.5) xtick(0(2)30) xlab(0(4)24,30) connect(llll) l2title("Annual Wage Rate relative to starting value") saving("brazempl/tex/v1/graphs/brpotx`yr'`gender'", replace)
    translate "brazempl/tex/v1/graphs/brpotx`yr'`gender'.gph" "brazempl/tex/v1/graphs/brpotx`yr'`gender'.eps", translator(gph2eps) replace
    more
    }
  }


set more off

cd "$home"
