version 8
clear
set matsize 180
set logtype text
set mem 900m
capture set mem 950m
set more off
adopath + "brazdspl/%stata/ado"

cd "$root"

local regname "edu"
foreach regname in indgrad edu noedu {

*YR forvalues yr = 90/98 {  /* 90/98 */
foreach yr in 90 97 {  /* 90 97 */
foreach sec in 1 2 4 5 {  /* 1 2 4 5 */

mat lnwcomp`regname'sec`sec'yr`yr' = J(9,4,-999)
mat rownames lnwcomp`regname'sec`sec'yr`yr' = wage lnwage xbhat xbhat_exper xbhat_occu xbhat_edu xbhat_sex psihat eiw
mat colnames lnwcomp`regname'sec`sec'yr`yr' = sqcoefvar theil mld gini

use "brazempl/est/v1/wagecomponents-`regname'-sec`sec'-`yr'", clear
sort lnwage workerid firmid plantid
foreach var in exper occu edu sex {
  rename pred_`var' xbhat_`var'
  label var xbhat_`var' "Xb (`var')"
  }
foreach var in lnwage xbhat /* xbhat_exper xbhat_occu xbhat_edu xbhat_sex psihat eiw */ {
  drop if `var'==.
  }
gen wage = exp(lnwage)
label var wage "Annual Avg. Wage (usd)"
order worker firm plant wage lnwage xbhat xbhat_exper xbhat_occu xbhat_edu xbhat_sex psihat eiw
qui summ wage, meanonly
local mu = `r(mean)'
qui summ lnwage, meanonly
local muln = `r(mean)'
local totn = `r(N)'

local col 0
foreach index in sqcoefvar theil mld gini {
  local col = `col' + 1
  local row = 1

  if "`index'"=="sqcoefvar"  gen double aterm = (wage - `mu')/`mu'^2                      /* GE(2) */
  if "`index'"=="theil"      gen double aterm = (1/`mu') * log(wage/`mu')                 /* GE(1) */
  if "`index'"=="mld"        gen double aterm = (1/wage) * log(`mu'/wage)                 /* GE(0) */
  if "`index'"=="gini"       gen double aterm = (2/(`totn'*`mu')) * (_n - (`totn'+1)/2 )  /* Gini  */
  gen double `index'_wage = aterm * wage
  qui summ `index'_wage, meanonly
  mat lnwcomp`regname'sec`sec'yr`yr'[`row',`col'] = `r(mean)'
  drop `index'_wage aterm

  if "`index'"=="sqcoefvar"  gen double atermln = (lnwage - `muln')/`muln'^2                  /* GE(2) */
  if "`index'"=="theil"      gen double atermln = (1/`muln') * log(lnwage/`muln')             /* GE(1) */
  if "`index'"=="mld"        gen double atermln = (1/lnwage) * log(`muln'/lnwage)             /* GE(0) */
  if "`index'"=="gini"       gen double atermln = (2/(`totn'*`muln')) * (_n - (`totn'+1)/2 )  /* Gini  */
  foreach var in lnwage xbhat xbhat_exper xbhat_occu xbhat_edu xbhat_sex psihat eiw {
    local row = `row' + 1
    gen double `index'_`var' = atermln * `var'
    qui summ `index'_`var', meanonly
    mat lnwcomp`regname'sec`sec'yr`yr'[`row',`col'] = `r(mean)'
    }
  * summ `index'*
  * egen double _chk = rsum(`index'_xbhat `index'_psihat `index'_eiw)
  * qui replace _chk = _chk - `index'_lnwage
  * qui summ _chk, meanonly
  * if `r(mean)' > .00001 {
  *   summ _chk, meanonly
  *   disp as error "Invalid component decomposition"
  *   STOP
  *   }
  * drop _chk
  drop `index'_* atermln

  } /* close index loop */

  * Coefficient of variation, GE(2)
  * correlate lnwage xbhat xbhat_exper xbhat_occu xbhat_edu xbhat_sex psihat eiw, covariance
  * matrix accum _cov`yr'sec`sec'`regname' = lnwage xbhat xbhat_exper xbhat_occu xbhat_edu xbhat_sex psihat eiw, nocons dev
  * matrix _cov`yr'sec`sec'`regname' = _cov`yr'sec`sec'`regname'/(`totn'*`muln'^2)
  * mat list _cov`yr'sec`sec'`regname'
  * disp _cov`yr'sec`sec'`regname'[2,1] + _cov`yr'sec`sec'`regname'[7,1] + _cov`yr'sec`sec'`regname'[8,1] - _cov`yr'sec`sec'`regname'[1,1]

  mat lnwcomp`regname'sec`sec'yr`yr'_tbl = lnwcomp`regname'sec`sec'yr`yr'
  mat drop lnwcomp`regname'sec`sec'yr`yr'
  est2tex lnwcomp`regname'sec`sec'yr`yr', replace dropall ready digits(5) fancy p(brazempl/tex/v1/corr)

  } /* close sec loop */
 } /* close yr loop */
} /* close regname loop */

cd "$home"
