version 8
clear
set matsize 180
set more off
adopath + "brazdspl/%stata/ado"

cd "$root"


/* Load variable names and save for est2tex */

insheet using "brazempl/tex/regressor-list.tex", delimiter("&") clear
rename v1 _rowname
rename v2 _rowlbl
replace _rowname = trim(_rowname)
replace _rowlbl = trim(_rowlbl)
drop if _rowname=="" & _rowlbl==""
sort _rowname
compress
save "brazempl/tex/v1/tables/Xfirmcomp_rowlbl", replace
clear


/* Load estimates */

*YR foreach yr in 90 92 93 94 95 96 97 98 {
foreach yr in 90 97 {
  matload Xfirm`yr'pia_tbl, path(brazempl/tex/v1/sec) over
  }


/* Estimation Tables for PIA Firms: Brazil 1990 and 1997 */

* Firm performance variables
mat _frmpia90 = Xfirm90pia_tbl[1..19,1..3] , Xfirm90pia_tbl[1..19,9]
mat _tmp1 = _frmpia90[1..4,1..4] \ _frmpia90[7,1..4]
mat _tmp1 = _tmp1 \ _frmpia90[10,1..4]
matrix roweq _tmp1 = 1990
mat _frmpia97 = Xfirm97pia_tbl[1..19,1..3] , Xfirm97pia_tbl[1..19,9]
mat _tmp2 = _frmpia97[1..4,1..4] \ _frmpia97[7,1..4]
mat _tmp2 = _tmp2 \ _frmpia97[10,1..4]
matrix roweq _tmp2 = 1997
mat Xfirmperf_tbl = _tmp1 \ _tmp2
local colnams : colnames Xfirmperf_tbl
local colmax = colsof(Xfirmperf_tbl)
tokenize `colnams'
forvalues i = 1/`colmax' {
    local coltitl = subinstr(subinstr("``i''","90","",.),"97","",.)
    matname Xfirmperf_tbl `coltitl', columns(`i') explicit
    }
mat drop _tmp1 _tmp2
est2tex Xfirmperf, replace dropall preserve ready mark(it) path(brazempl/tex/v1/tables) fancy

* Non-labor input variables
mat _tmp1 = Xfirm90pia_tbl[1..4,4..8] \ Xfirm90pia_tbl[7,4..8]
mat _tmp1 = _tmp1 \ Xfirm90pia_tbl[10,4..8]
matrix roweq _tmp1 = 1990
mat _tmp2 = Xfirm97pia_tbl[1..4,4..8] \ Xfirm97pia_tbl[7,4..8]
mat _tmp2 = _tmp2 \ Xfirm97pia_tbl[10,4..8]
matrix roweq _tmp2 = 1997
mat Xfirminp_tbl = _tmp1 \ _tmp2
mat Xfirminp_tbl = Xfirminp_tbl[1..12,1..3] , Xfirminp_tbl[1..12,5] , Xfirminp_tbl[1..12,4]
local colnams : colnames Xfirminp_tbl
local colmax = colsof(Xfirminp_tbl)
tokenize `colnams'
forvalues i = 1/`colmax' {
    local coltitl = subinstr(subinstr("``i''","90","",.),"97","",.)
    matname Xfirminp_tbl `coltitl', columns(`i') explicit
    }
est2tex Xfirminp, replace dropall preserve ready mark(it) path(brazempl/tex/v1/tables) fancy


/* Firm-regression comparison tables to France and US */

tempfile br90comp
local colnams : colnames Xfirm90pia_tbl
tokenize `colnams'
mat Xfirmcomp90_tbl = Xfirm90pia_tbl[1..4,1]
matrix roweq Xfirmcomp90_tbl = `1'
forvalues j = 2/9 {
    mat _tmp = Xfirm90pia_tbl[1..4,`j']
    matrix roweq _tmp = ``j''
    mat Xfirmcomp90_tbl = Xfirmcomp90_tbl \ _tmp
    matname Xfirmcomp90_tbl br90, columns(1) explicit
    }
mat drop _tmp
matsave Xfirmcomp90_tbl, replace path(brazempl/tex/v1/tables)
use "brazempl/tex/v1/tables/Xfirmcomp90_tbl", clear
gen _brno = _n
preserve
    keep if substr(_rowname,-3,3)=="_se"
    sort _brno
    rename _brno _brnosd
    rename br90 br90se
    save `br90comp'
restore
drop if substr(_rowname,-3,3)=="_se"
sort _brno
merge using `br90comp'
drop _br* _m
save "brazempl/tex/v1/tables/Xfirmcomp90_tbl", replace
drop _all
matload Xfirmcomp90_tbl, over path(brazempl/tex/v1/tables)
mat brXfirmcomp90_tbl = Xfirmcomp90_tbl
insheet using "brazempl/auxil/akmt-firm-secfe.csv", comma names clear
foreach var in fr92 us90 {
    replace `var'sd = abs(`var'sd)
    }
keep _rowname fr92* us90*
drop if fr92c==. & fr92s==. & us90c==. & us90s==.
save "brazempl/tex/v1/tables/Xfirmcomp90_tbl", replace
drop _all
matload Xfirmcomp90_tbl, over path(brazempl/tex/v1/tables)
mat Xfirmcomp90_tbl = Xfirmcomp90_tbl \ J(2,4,-999)
mat Xfirmcomp90_tbl = brXfirmcomp90_tbl , Xfirmcomp90_tbl
mat drop brXfirmcomp90_tbl
mat Xfirmcomp90_b = Xfirmcomp90_tbl[1..18,1] , Xfirmcomp90_tbl[1..18,3] , Xfirmcomp90_tbl[1..18,5]
mat Xfirmcomp90_se = Xfirmcomp90_tbl[1..18,2] , Xfirmcomp90_tbl[1..18,4] , Xfirmcomp90_tbl[1..18,6]
est2tex Xfirmcomp90, replace dropall preserve mark(it) path(brazempl/tex/v1/tables) fancy

tempfile br97comp
local colnams : colnames Xfirm97pia_tbl
tokenize `colnams'
mat Xfirmcomp97_tbl = Xfirm97pia_tbl[1..4,1]
matrix roweq Xfirmcomp97_tbl = `1'
forvalues j = 2/9 {
    mat _tmp = Xfirm97pia_tbl[1..4,`j']
    matrix roweq _tmp = ``j''
    mat Xfirmcomp97_tbl = Xfirmcomp97_tbl \ _tmp
    matname Xfirmcomp97_tbl br97, columns(1) explicit
    }
mat drop _tmp
matsave Xfirmcomp97_tbl, replace path(brazempl/tex/v1/tables)
use "brazempl/tex/v1/tables/Xfirmcomp97_tbl", clear
gen _brno = _n
preserve
    keep if substr(_rowname,-3,3)=="_se"
    sort _brno
    rename _brno _brnosd
    rename br97 br97se
    save `br97comp'
restore
drop if substr(_rowname,-3,3)=="_se"
sort _brno
merge using `br97comp'
drop _br* _m
save "brazempl/tex/v1/tables/Xfirmcomp97_tbl", replace
drop _all
matload Xfirmcomp97_tbl, over path(brazempl/tex/v1/tables)
mat brXfirmcomp97_tbl = Xfirmcomp97_tbl
insheet using "brazempl/auxil/akmt-firm-secfe.csv", comma names clear
foreach var in fr92 us90 {
    replace `var'sd = abs(`var'sd)
    }
keep _rowname fr92* us90*
drop if fr92c==. & fr92s==. & us90c==. & us90s==.
save "brazempl/tex/v1/tables/Xfirmcomp97_tbl", replace
drop _all
matload Xfirmcomp97_tbl, over path(brazempl/tex/v1/tables)
mat Xfirmcomp97_tbl = Xfirmcomp97_tbl \ J(2,4,-999)
mat Xfirmcomp97_tbl = brXfirmcomp97_tbl , Xfirmcomp97_tbl
mat drop brXfirmcomp97_tbl
mat Xfirmcomp97_b = Xfirmcomp97_tbl[1..18,1] , Xfirmcomp97_tbl[1..18,3] , Xfirmcomp97_tbl[1..18,5]
mat Xfirmcomp97_se = Xfirmcomp97_tbl[1..18,2] , Xfirmcomp97_tbl[1..18,4] , Xfirmcomp97_tbl[1..18,6]
est2tex Xfirmcomp97, replace dropall preserve mark(it) path(brazempl/tex/v1/tables) fancy

mat Xfirmcomp_tbl = Xfirmcomp90_tbl , Xfirmcomp97_tbl[1..36,1]
mat drop Xfirmcomp90_tbl
mat drop Xfirmcomp97_tbl
est2tex Xfirmcomp, replace dropall preserve ready mark(it) path(brazempl/tex/v1/tables) fancy
mat drop Xfirmcomp_tbl


cd "$home"
