version 8
clear
set matsize 300
set logtype text
set mem 900m
capture set mem 950m
set more off
adopath + "brazdspl/%stata/ado"

cd "$root"

capture mkdir "brazempl/tex/pnad/nonparam"

local sec 4

capture log close
log using "brazempl/logs/nonparam-pnad-rais.log", replace

capture program drop corrxttab
program define corrxttab
    args regname yr sec infrm one
    predict double xbhat if e(sample)
    replace xbhat = xbhat - _coef[_cons]
    predict double psihat, u
    replace psihat = psihat + _coef[_cons]
    predict double eiw, e
    gen double bpsc = _b[psc] * psc
    corr lnwage xbhat psihat eiw bpsc
    matrix accum corr`yr'sec`sec'`regname' = lnwage xbhat psihat eiw bpsc, nocons dev means(corr`yr'sec`sec'`regname'_means)
    matrix corr`yr'sec`sec'`regname'_sdev = corr`yr'sec`sec'`regname'_means
    local j 0
    foreach var in lnwage xbhat psihat eiw bpsc {
        local j = `j' + 1
        qui summ `var'
        local entry = int(`r(sd)'*10000)/10000
        matrix corr`yr'sec`sec'`regname'_sdev[1,`j']=`entry'
        }
    matrix corr`yr'sec`sec'`regname'_tbl = corr(corr`yr'sec`sec'`regname')
    matrix corr`yr'sec`sec'`regname'_tbl = corr`yr'sec`sec'`regname'_sdev ' , corr`yr'sec`sec'`regname'_tbl
    matrix corr`yr'sec`sec'`regname'_tbl = corr`yr'sec`sec'`regname'_means ' , corr`yr'sec`sec'`regname'_tbl
    matname corr`yr'sec`sec'`regname'_tbl mean sdev, columns(1..2) explicit
    drop xbhat psihat eiw bpsc
end

capture program drop hosets
program define hosets
    version 8.2
    args regtype

    capture confirm numeric variable indprof indtech indwhit indsklb 
    if _rc == 0 {
      local occulst "indprof indtech indwhit indsklb"
      }
    foreach var in potexper potxper2 potxper3 potxper4 indschlg1 indschlg2 indschlg3 indschlg4 indschlg5 indschlg6 indschlg7 indschlg8 indprim indhigh indprim_alt indhigh_alt indscoll indgrad indblue `occulst' {
      local dattyp = ""
      if substr("`var'",1,3)=="ind" {
          local dattyp = "byte"
          }
      gen `dattyp' fem_`var' = indfem * `var'
      local lbl : variable label `var'
      local lbl = subinstr("`lbl'"," (at plant)","",.)
      local lbl = subinstr("`lbl'"," Term","",.)
      local lbl = subinstr("`lbl'"," Occupation","",.)
      local lbl = subinstr("`lbl'"," Education","",.)
      local lbl = "Fem. " + "`lbl'" + " Interact."
      label var fem_`var' "`lbl'"
      }
    compress
    drop sector

    if "`regtype'"=="nonparam" {
      global selvars "potexper potxper2 potxper3 potxper4 indschlg1 indschlg2 indschlg3 indschlg4 indschlg5 indschlg6 indschlg7 indschlg8 indfem fem_potexper fem_potxper2 fem_potxper3 fem_potxper4 fem_indschlg1 fem_indschlg2 fem_indschlg3 fem_indschlg4 fem_indschlg5 fem_indschlg6 fem_indschlg7 fem_indschlg8"
      forvalues i = 1/4 {
        foreach var in indschlg1 indschlg2 indschlg3 indschlg4 indschlg5 indschlg6 indschlg7 indschlg8 indfem {
          local pname = "potx`i'"
          local vname = subinstr("`var'","ind","",.)
          if `i'==1  qui gen set1_`pname'_`vname' = potexper * `var'
          else       qui gen set1_`pname'_`vname' = potxper`i' * `var'
          }
        foreach var in indschlg1 indschlg2 indschlg3 indschlg4 indschlg5 indschlg6 indschlg7 indschlg8 {
          local pname = "fem_potx`i'"
          local vname = subinstr("`var'","ind","",.)
          if `i'==1  qui gen set2_`pname'_`vname' = fem_potexper * `var'
          else       qui gen set2_`pname'_`vname' = fem_potxper`i' * `var'
          }
        }
      }
    if "`regtype'"=="nonpblu" {
      global selvars "potexper potxper2 potxper3 potxper4 indschlg1 indschlg2 indschlg3 indschlg4 indschlg5 indschlg6 indschlg7 indschlg8 indblu indfem fem_potexper fem_potxper2 fem_potxper3 fem_potxper4 fem_indschlg1 fem_indschlg2 fem_indschlg3 fem_indschlg4 fem_indschlg5 fem_indschlg6 fem_indschlg7 fem_indschlg8 fem_indblu"
      forvalues i = 1/4 {
        foreach var in indschlg1 indschlg2 indschlg3 indschlg4 indschlg5 indschlg6 indschlg7 indschlg8 indblu indfem {
          local pname = "potx`i'"
          local vname = subinstr("`var'","ind","",.)
          if `i'==1  qui gen set1_`pname'_`vname' = potexper * `var'
          else       qui gen set1_`pname'_`vname' = potxper`i' * `var'
          }
        foreach var in indschlg1 indschlg2 indschlg3 indschlg4 indschlg5 indschlg6 indschlg7 indschlg8 indblu {
          local pname = "fem_potx`i'"
          local vname = subinstr("`var'","ind","",.)
          if `i'==1  qui gen set2_`pname'_`vname' = fem_potexper * `var'
          else       qui gen set2_`pname'_`vname' = fem_potxper`i' * `var'
          }
        }
      }
end

local indedu "potexper potxper2 potxper3 potxper4 indprim indhigh indscoll indprof indtech indwhit indsklb indfem fem_potexper fem_potxper2 fem_potxper3 fem_potxper4 fem_indprim fem_indhigh fem_indscoll fem_indprof fem_indtech fem_indwhit fem_indsklb"
local indblu "potexper potxper2 potxper3 potxper4 indprim indhigh indscoll                         indblue indfem fem_potexper fem_potxper2 fem_potxper3 fem_potxper4 fem_indprim fem_indhigh fem_indscoll                                     fem_indblue"

foreach regtype in nonpblu nonparam {

if "`regtype'"=="nonparam"  local data = "edu"
if "`regtype'"=="nonpblu"   local data = "blu"

*YR forvalues yr = 90/98 {}  /* 90/98 */
foreach yr in 90 97 {  /* 90 97 */
    use "brazempl/pnad/use-pnad-`yr'", clear
    replace lnwage = . if indinfrm==1
    gen byte indselct = 1 - indinfrm
    label var indselct "Formality Selection"
    local secname : label sector `sec'
    disp
    disp in green "Year: " in yellow "19`yr'" in green ", Sector: " in yellow "`sec'" in green " (" in yellow "`secname'" in green ")"
    disp
    * tab sector
    * tab sector, nolab
    keep if sector==`sec'
    sort worker

    hosets `regtype'
    keep indselct lnwage $selvars potexper potxper2 potxper3 potxper4 indprim indhigh indscoll indfem fem_potexper fem_potxper2 fem_potxper3 fem_potxper4 fem_indprim fem_indhigh fem_indscoll set1_* set2_* indblue fem_indblue
    order lnwage $selvars 

    /* Cross-validated regression on PNAD data */
    reg indselct $selvars set1_* set2_*, nocons

    /* Out-of-sample prediction on RAIS data */
    use workerid plantid sector lnwage potexper potxper2 potxper3 potxper4 indschlg1 indschlg2 indschlg3 indschlg4 indschlg5 indschlg6 indschlg7 indschlg8 indfem indprim* indhigh* indscoll indgrad indfem indprof indtech indwhit indsklb using "brazempl/use-brazempl-`yr'" if sector==`sec', clear
    gen byte indblue = (indprof==0 & indtech==0 & indwhit==0)
    label var indblue "Blue-collar occupation"
    qui hosets `regtype'
    order workerid plantid lnwage $selvars potexper potxper2 potxper3 potxper4 indprim indhigh indscoll indfem fem_potexper fem_potxper2 fem_potxper3 fem_potxper4 fem_indprim fem_indhigh fem_indscoll set1_* set2_*
    predict double psc, xb
    label var psc "Propensity score"
    gen double psc2 = psc*psc
    label var psc2 "Squared propensity score"
    tempvar one
    gen byte `one' = 1
    iis plant       
    keep plant lnwage `ind`data'' psc psc2

    xtreg lnwage `ind`data'' psc psc2, fe
    capture local chkexst = colsof(wage`yr'sec`sec'_b)
    if _rc~=0  est2vec wage`yr'sec`sec', vars(potexper potxper2 potxper3 potxper4 tenuryr tenr2 tenr3 tenr4 indschlg1 indschlg2 indschlg3 indschlg4 indschlg5 indschlg6 indschlg7 indschlg8 indprim indhigh indprim_alt indhigh_alt indscoll indgrad indprof indtech indwhit indsklb indunsklb indblue indfem fem_potexper fem_potxper2 fem_potxper3 fem_potxper4 fem_tenuryr fem_tenr2 fem_tenr3 fem_tenr4 fem_indschlg1 fem_indschlg2 fem_indschlg3 fem_indschlg4 fem_indschlg5 fem_indschlg6 fem_indschlg7 fem_indschlg8 fem_indprim fem_indhigh fem_indprim_alt fem_indhigh_alt fem_indscoll fem_indgrad fem_indprof fem_indtech fem_indwhit fem_indsklb fem_indunsklb fem_indblue _cons psc psc2) e(r2 r2_a r2_w r2_o r2_b mss tss corr sigma_u sigma_e df_r df_m) name(yr`yr'sec`sec'`data'psc2)
    else       est2vec wage`yr'sec`sec', addto(wage`yr'sec`sec') name(yr`yr'sec`sec'`data'psc2)
    drop psc2
    
    xtreg lnwage `ind`data'' psc, fe
    est2vec wage`yr'sec`sec', addto(wage`yr'sec`sec') name(yr`yr'sec`sec'`data'psc)
    corrxttab `regtype' `yr' `sec' xtreg `one'

    xtreg lnwage `ind`data'', fe
    est2vec wage`yr'sec`sec', addto(wage`yr'sec`sec') name(yr`yr'sec`sec'`data')

    }
  }

/* save results */
*YR forvalues yr = 90/98 {}  /* 90/98 */
foreach yr in 90 97 {  /* 90 97 */
  est2tex wage`yr'sec`sec', replace dropall mark(it) digits(4) fancy path(brazempl/tex/nonparam) label
  *SEC foreach regtype in nonparam nonpblu {
  foreach regtype in nonparam {  /* insufficient memory for indblue interactions */
    est2tex corr`yr'sec`sec'`regtype', replace dropall preserve ready digits(4) fancy path(brazempl/tex/nonparam)
    }
  }

log close
cd "$home"
