* v1: lnwage (annual average monthly wage, used in paper)
* v2: lndecwage (annualized December wage, NOT used in paper)

program drop _all
global root "c:/data/"
* global root "//acsnfs4/unix-home/econgrad/marcm/"
global home "c:/data/"
* global home "//acsnfs4/unix-home/econgrad/marcm/"

clear
set more off
set virtual on
* set trace on
set matsize 150

cd "$home"
adopath + "brazaux/%stata/ado"
adopath + "brazempl/%stata/ado"


* DATA PREPARATION
*-----------------

* do "brazempl/%stata/%1prep-data/repl-data.do"
    /* CREATE WORKER DATA SET FOR ESTIMATION (similar to rais-sp:firmempl.do) */
    /* INPUT:  "brazaux/auxil/minwage.dta" (where `yr' in 90 through 98) 
               "rais/cbo/cbo2isco.dta"
               "rais-sp/rais/19`yr'/`sector'`yr'.dta" (where `sector' in "Agriculture" "Commerce" "Construction" "Manufacturing" "Services" "Other", `yr' in 90 through 98) */
    /* OUTPUT: "brazempl/use-brazempl-`yr'.dta" (where `yr' in 90 through 98)
               "brazempl/data/firm-skills-`yr'.dta" (where `yr' in 90 through 98) */
    /*   Logs: "brazempl/logs/repl-data.log" */ 

* do "brazempl/%stata/%1prep-data/cnae-niv50.do"
    /* MAP CNAE 1997 PER RAIS FIRM TO NIV50 */
    /* INPUT:  "rais-sp/raisraw/cnae/cnae`yr'" (where `yr' in 90 through 98) 
               "brazcomp/filters/cnae-niv-naic.dta" */
    /* OUTPUT: "brazempl/data/firms-niv50.dta"  */
    /*   Logs: "brazempl/logs/cnae-niv50.log" */ 

* do "brazempl/%stata/%1prep-data/missing-cbo-from-log.do"
    /* LIST OF MISSING CBO CODES */
    /* INPUT:  "brazempl/cbo-conc/missing-cbo-fromlog.txt" */
    /* OUTPUT: "brazempl/cbo-conc/missing-cbo-fromlog.dta"  */
    /*   Logs: none */ 


* EMPLOYER AND EMPLOYMENT EFFECTS
*--------------------------------

* do "brazempl/%stata/%2empl-effects/xtreg-worker-plantfe.do"
    /* ESTIMATE PLANT-WORKER FIXED EFFECTS MODEL  */
    /* INPUT:  "brazempl/use-brazempl-`yr'.dta" (where `yr' in 90 through 98) */
    /* OUTPUT: "brazempl/est/v1/firmpred-indgrad-sec`sec'-`yr'.dta" (where `yr' in 90 through 98, `sec' in 1 2 4 5)
               "brazempl/est/v1/firmpred-edu-sec`sec'-`yr'.dta" (where `yr' in 90 through 98, `sec' in 1 2 4 5)
               "brazempl/est/v1/firmpred-noedu-sec`sec'-`yr'.dta" (where `yr' in 90 through 98, `sec' in 1 2 4 5)
               "brazempl/est/v1/wagecomponents-indgrad-sec`sec'-`yr'.dta" (where `yr' in 90 through 98, `sec' in 1 2 4 5)
               "brazempl/est/v1/wagecomponents-edu-sec`sec'-`yr'.dta" (where `yr' in 90 through 98, `sec' in 1 2 4 5)
               "brazempl/est/v1/wagecomponents-noedu-sec`sec'-`yr'.dta" (where `yr' in 90 through 98, `sec' in 1 2 4 5)
       Tables: "brazempl/tex/v1/corr/corr`yr'sec`sec'indgrad_tbl.dta", "brazempl/tex/v1/corr/corr`yr'sec`sec'indgrad.tex" (where `yr' in 90 through 98, where `sec' in 1 2 4 5) 
               "brazempl/tex/v1/corr/corr`yr'sec`sec'edu_tbl.dta", "brazempl/tex/v1/corr/corr`yr'sec`sec'edu.tex" (where `yr' in 90 through 98, where `sec' in 1 2 4 5) 
               "brazempl/tex/v1/corr/corr`yr'sec`sec'noedu_tbl.dta", "brazempl/tex/v1/corr/corr`yr'sec`sec'noedu.tex" (where `yr' in 90 through 98, where `sec' in 1 2 4 5) 
               "brazempl/tex/v1/wage/wage`yr'sec`sec'_tbl.dta", "brazempl/tex/v1/wage/wage`yr'sec`sec'.tex" (where `yr' in 90 through 98, where `sec' in 1 2 4 5) */
    /*   Logs: "brazempl/logs/xtreg-worker-plantfe-round`run'.log" (where `run' counts repetitions of the procedure) */ 

* do "brazempl/%stata/%2empl-effects/reg-worker-plain.do"
    /* ESTIMATE PLAIN MODEL WITHOUT FIXED EFFECTS */
    /* INPUT:  "brazempl/use-brazempl-`yr'.dta" (where `yr' in 90 through 98) */
    /* OUTPUT: "brazempl/est/v1/wageplaincomponents-indgrad-sec`sec'-`yr'.dta" (where `yr' in 90 through 98, `sec' in 1 2 4 5)
               "brazempl/est/v1/wageplaincomponents-edu-sec`sec'-`yr'.dta" (where `yr' in 90 through 98, `sec' in 1 2 4 5)
               "brazempl/est/v1/wageplaincomponents-noedu-sec`sec'-`yr'.dta" (where `yr' in 90 through 98, `sec' in 1 2 4 5)
       Tables: "brazempl/tex/v1/corr/corrplain`yr'sec`sec'indgrad_tbl.dta", "brazempl/tex/v1/corr/corrplain`yr'sec`sec'indgrad.tex" (where `yr' in 90 through 98, where `sec' in 1 2 4 5) 
               "brazempl/tex/v1/corr/corrplain`yr'sec`sec'edu_tbl.dta", "brazempl/tex/v1/corr/corrplain`yr'sec`sec'edu.tex" (where `yr' in 90 through 98, where `sec' in 1 2 4 5) 
               "brazempl/tex/v1/corr/corrplain`yr'sec`sec'noedu_tbl.dta", "brazempl/tex/v1/corr/corrplain`yr'sec`sec'noedu.tex" (where `yr' in 90 through 98, where `sec' in 1 2 4 5) 
               "brazempl/tex/v1/wage/wageplain`yr'sec`sec'_tbl.dta", "brazempl/tex/v1/wage/wageplain`yr'sec`sec'.tex" (where `yr' in 90 through 98, where `sec' in 1 2 4 5) */
    /*   Logs: "brazempl/logs/reg-worker-plain-round`run'.log" (where `run' counts repetitions of the procedure) */ 

* do "brazempl/%stata/%2empl-effects/repl-pia-data.do"
    /* CREATE FIRM-LEVEL DATA SET FOR ESTIMATION */
    /* INPUT:  "brazdspl/pia/random-3firm-firmlist-rndmnr.dta"
               "brazdspl/pia/random-3firm-grpid-rndmnr.dta"
               "brazempl/data/firm-skills-`yr'.dta" (where `yr' in 90, 92 through 98)
               "brazempl/est/v1/firmpred-edu-sec`sec'-`yr'.dta" (where `sec' in 1 2 4 5; `yr' in 90, 92 through 98) 
               "brazdspl/pia/prodcoeff-brazprod.dta" (from brazaux:pia-random-agg:prep-tfp.do)
               "brazaux/auxil/niv50.do" */
    /* OUTPUT: "brazempl/use-firms-`yr'.dta" (where `yr' in 90, 92 through 98) 
         Logs: "brazempl/logs/repl-pia-data.log" (where `run' counts repetitions of the procedure) */ 

* do "brazempl/%stata/%2empl-effects/xtreg-firm-secfe.do"
    /* ESTIMATE (confidential) FIRM-LEVEL MODEL WITH SECTOR-LEVEL FIXED EFFECTS (at IBGE) */
    /* INPUT:  "brazempl/use-firms-`yr'.dta" (where `yr' in 90, 92 through 98) */
    /* OUTPUT: (none)
       Tables: "brazempl/tex/v1/sec/firmpia_tbl.dta", "brazempl/tex/v1/sec/firmpia.tex" 
               "brazempl/tex/v1/sec/firm`yr'pia_tbl.dta", "brazempl/tex/v1/sec/firm`yr'pia.tex" (where `yr' in 90, 92 through 98) */
    /*   Logs: "brazempl/logs/xtreg-firm-secfe.log" */ 

* do "brazempl/%stata/%2empl-effects/xtreg-wrkrfrmfe-reg.do"
    /* CORRELATE AVG. WORKER-FIRM FIXED EFFECTS WITH MACRO VARIABLES */
    /* INPUT:  "brazempl/use-firms-`yr'.dta" (where `yr' in 90, 92 through 98) 
               "brazaux/auxil/seclvl.dta" */
    /* OUTPUT: "brazempl/tex/v1/sec/wrkrfrmfe_tbl.dta", "brazempl/tex/v1/sec/wrkrfrmfe.tex" */
    /*   Logs: "brazempl/logs/xtreg-wrkrfrmfe-reg.log" */ 

* do "brazempl/%stata/%2empl-effects/xtreg-sec-secfe.do"
    /* CORRELATE AVG. WORKER-FIRM FIXED EFFECTS WITH MACRO VARIABLES */
    /* INPUT:  "brazempl/use-firms-`yr'.dta" (where `yr' in 90, 92 through 98)
               "brazaux/auxil/seclvl.dta" */
    /* OUTPUT: "brazempl/tex/v1/sec/secpia_tbl.dta", "brazempl/tex/v1/sec/secpia.tex" */
    /*   Logs: "brazempl/logs/xtreg-sec-secfe.log" */ 


* TABLES AND GRAPHS
*------------------

* do "brazempl/%stata/%3tables-graphs/summdata.do"
    /* SUMMARIZE WORKER DATA BY YEAR */
    /* INPUT:  "brazempl/use-brazempl-`yr'.dta" (where `yr' in 90 through 98) 
               "brazempl/use-firms-`yr'.dta"
               "brazdspl/pia/random-3firm-firmlist-rndmnr.dta"
               "brazaux/auxil/seclvl.dta" */
    /* OUTPUT: (none)
       Tables: "brazempl/tex/v1/summ/summtex`yr'sec`sec'_tbl.dta", "brazempl/tex/v1/summ/summtex`yr'sec`sec'.tex" (where `yr' in 90 through 98, `sec' in 1 2 4 5)
               "brazempl/tex/v1/summ/lnwmean`yr'`var'.dta", "brazempl/tex/v1/summ/lnwmean`yr'`var'_tbl.tex" (where `yr' in 90 97 and `var' in indfem indblue indnocoll)
               "brazempl/tex/v1/summ/sdv`yr'`var'.dta", "brazempl/tex/v1/summ/sdv`yr'`var'_tbl.tex" (where `yr' in 90 97 and `var' in indfem indblue indnocoll)
               "brazempl/tex/v1/summ/count`yr'`var'.dta", "brazempl/tex/v1/summ/count`yr'`var'_tbl.tex" (where `yr' in 90 97 and `var' in indfem indblue indnocoll) 
               "brazempl/tex/v1/summ/piacnt_tbl.dta", "brazempl/tex/v1/summ/piacnt.tex" 
               "brazempl/tex/v1/summ/summtex`yr'pia" (where `yr' in 90 97) */

* do "brazempl/%stata/%3tables-graphs/experience.do"
    /* POTENTIAL EXPERIENCE TABLES AND GRAPHS */
    /* INPUT:  "brazempl/tex/v1/wage/wage`yr'sec`sec'_tbl.dta" (where `yr' in 90 through 98, `sec' in 1 2 4 5) 
               "brazempl/tex/v1/corr/corr`yr'sec`sec'_tbl.dta" (where `yr' in 90 through 98, `sec' in 1 2 4 5) 
               "brazempl/tex/v1/summ/summtex`yr'sec`sec'_tbl.dta" (where `yr' in 90 through 98, `sec' in 1 2 4 5) 
               "brazempl/auxil/akmt-worker-plantfe.csv" 
               "brazempl/auxil/akmt-summdata.csv" 
               "brazempl/auxil/fr92edu.csv" 
               "brazempl/auxil/us90edu.csv" */
    /* OUTPUT: "brazempl/auxil/akmtb.dta"
               "brazempl/auxil/akmtpotx.dta"
               "brazempl/auxil/akmtmean.dta"
               "brazempl/est/v1/mmr`yr'sec`sec'.dta" (where `yr' in 90 through 98, `sec' in 1 2 4 5) 
       Tables: "brazempl/tex/v1/tables/comp_tbl.dta", "brazempl/tex/v1/tables/comp.tex"
               "brazempl/tex/v1/tables/brazpotx_tbl.dta", "brazempl/tex/v1/tables/brazpotx.tex"
       Graphs: "brazempl/tex/v1/graphs/potx`gender'.gph"
               "brazempl/tex/v1/graphs/brpotx`yr'`gender'.gph" */

* do "brazempl/%stata/%3tables-graphs/edu-occu-sex.do"
    /* EDUCATION, OCCUPATION, GENDER TABLES AND GRAPHS */
    /* INPUT:  "brazempl/tex/v1/wage/wage`yr'sec`sec'_tbl.dta" (where `yr' in 90 through 98, `sec' in 1 2 4 5) 
               "brazempl/tex/v1/corr/corr`yr'sec`sec'_tbl.dta" (where `yr' in 90 through 98, `sec' in 1 2 4 5) 
               "brazempl/tex/v1/summ/summtex`yr'sec`sec'_tbl.dta" (where `yr' in 90 through 98, `sec' in 1 2 4 5) 
               "brazempl/auxil/akmt-worker-plantfe.csv" 
               "brazempl/auxil/akmt-summdata.csv" 
               "brazempl/auxil/fr92edu.csv" 
               "brazempl/auxil/us90edu.csv" */
    /* OUTPUT: "brazempl/auxil/akmtb`profile'out.dta" (where `profile' in edu occu)
               "brazempl/auxil/akmtb`profile'in.dta" (where `profile' in edu occu)
               "brazempl/auxil/akmtmean`profile'out.dta" (where `profile' in edu occu)
               "brazempl/auxil/akmtbsexmasc.dta"
               "brazempl/auxil/akmtbsexfemi.dta"
               "brazempl/auxil/akmtmeansexmasc.dta"
       Tables: "brazempl/tex/v1/tables/prflcomp`profile'_tbl.dta", "brazempl/tex/v1/prflcomp`profile'.tex" (where `profile' in edu occu sex)
               "brazempl/tex/v1/tables/prflbrsec`profile'_tbl.dta", "brazempl/tex/v1/prflbrsec`profile'.tex" (where `profile' in edu occu sex) */

* do "brazempl/%stata/%3tables-graphs/income-components.do"
    /* DECOMPOSE WAGE INEQUALITY BY INCOME COMPONENT FROM PLANT-WORKER FIXED EFFECTS MODEL  */
    /* INPUT:  "brazempl/brazempl/est/v1/wagecomponents-`regname'-sec`sec'-`yr'.dta" (where `regname' in edu occu sex, `sec' in 1 2 4 5, `yr' in 90 through 98) */
    /* OUTPUT: none
       Tables: "brazempl/tex/v1/lnwcomp`regname'sec`sec'yr`yr'_tbl.dta", "brazempl/tex/v1/lnwcomp`regname'sec`sec'yr`yr'.tex" (where `regname' in edu occu sex, `sec' in 1 2 4 5, `yr' in 90 through 98) */

* do "brazempl/%stata/%3tables-graphs/experience-plain.do"
    /* PLAIN REGRESSIONS: POTENTIAL EXPERIENCE TABLES AND GRAPHS */
    /* INPUT:  "brazempl/tex/v1/wage/wageplain`yr'sec`sec'_tbl.dta" (where `yr' in 90 through 98, `sec' in 1 2 4 5) 
               "brazempl/tex/v1/corr/corrplain`yr'sec`sec'_tbl.dta" (where `yr' in 90 through 98, `sec' in 1 2 4 5) 
               "brazempl/tex/v1/summ/summtex`yr'sec`sec'_tbl.dta" (where `yr' in 90 through 98, `sec' in 1 2 4 5) 
               "brazempl/auxil/akmt-worker-plantfe.csv" 
               "brazempl/auxil/akmt-summdata.csv" 
               "brazempl/auxil/fr92edu.csv" 
               "brazempl/auxil/us90edu.csv" */
    /* OUTPUT: "brazempl/auxil/akmtb.dta"
               "brazempl/auxil/akmtpotx.dta"
               "brazempl/auxil/akmtmean.dta"
               "brazempl/est/v1/mmrplain`yr'sec`sec'.dta" (where `yr' in 90 through 98, `sec' in 1 2 4 5) 
       Tables: "brazempl/tex/v1/tables/compplain_tbl.dta", "brazempl/tex/v1/tables/comp.tex"
               "brazempl/tex/v1/tables/brazpotxplain_tbl.dta", "brazempl/tex/v1/tables/brazpotx.tex"
       Graphs: "brazempl/tex/v1/graphs/potxplain`gender'.gph"
               "brazempl/tex/v1/graphs/brpotxplain`yr'`gender'.gph" */

* do "brazempl/%stata/%3tables-graphs/edu-occu-sex-plain.do"
    /* PLAIN REGRESSIONS: EDUCATION, OCCUPATION, GENDER TABLES AND GRAPHS */
    /* INPUT:  "brazempl/tex/v1/wage/wageplain`yr'sec`sec'_tbl.dta" (where `yr' in 90 through 98, `sec' in 1 2 4 5) 
               "brazempl/tex/v1/corr/corrplain`yr'sec`sec'_tbl.dta" (where `yr' in 90 through 98, `sec' in 1 2 4 5) 
               "brazempl/tex/v1/summ/summtex`yr'sec`sec'_tbl.dta" (where `yr' in 90 through 98, `sec' in 1 2 4 5) 
               "brazempl/auxil/akmt-worker-plantfe.csv" 
               "brazempl/auxil/akmt-summdata.csv" 
               "brazempl/auxil/fr92edu.csv" 
               "brazempl/auxil/us90edu.csv" */
    /* OUTPUT: 
       Tables: "brazempl/tex/v1/tables/prflcompplain`profile'_tbl.dta", "brazempl/tex/v1/prflcomp`profile'.tex" (where `profile' in edu occu sex)
               "brazempl/tex/v1/tables/prflbrsec`profile'_tbl.dta", "brazempl/tex/v1/prflbrsec`profile'.tex" (where `profile' in edu occu sec) */

* do "brazempl/%stata/%3tables-graphs/income-components-plain.do"
    /* DECOMPOSE WAGE INEQUALITY BY INCOME COMPONENT FROM PLANT-WORKER FIXED EFFECTS MODEL  */
    /* INPUT:  "brazempl/brazempl/est/v1/wageplaincomponents-`regname'-sec`sec'-`yr'.dta" (where `regname' in edu occu sex, `sec' in 1 2 4 5, `yr' in 90 through 98) */
    /* OUTPUT: none
       Tables: "brazempl/tex/v1/lnwplaincomp`regname'sec`sec'yr`yr'_tbl.dta", "brazempl/tex/v1/lnwplaincomp`regname'sec`sec'yr`yr'.tex" (where `regname' in edu occu sex, `sec' in 1 2 4 5, `yr' in 90 through 98) */

* do "brazempl/%stata/%3tables-graphs/tables-90-97.do"
    /* COMPARISONS 1990 and 1997; COMPARISONS BETWEEN BRAZIL, FRANCE, US */
    /* INPUT:  "brazempl/tex/v1/tables/prflcomp`profile'_tbl.dta" (where `profile' in edu occu sex)
               "brazempl/tex/v1/tables/prflbrsec`profile'_tbl.dta" (where `profile' in edu occu sex)
               "brazempl/tex/v1/tables/prflcompplain`profile'_tbl.dta" (where `profile' in edu occu sex)
               "brazempl/tex/v1/tables/prflbrsecplain`profile'_tbl.dta" (where `profile' in edu occu sex)
               "brazempl/tex/v1/sec/firm`yr'pia_tbl.dta"
               "brazempl/tex/v1/sec/firm`yr'sec`sec'_tbl.dta"
               "brazempl/tex/v1/summ/summtex`yr'sec`sec'_tbl.dta" 
               "brazempl/tex/v1/summ/lnwmean`yr'`var'.dta", "brazempl/tex/v1/summ/lnwmean`yr'`var'_tbl.tex" (where `yr' in 90 97 and `var' in indfem indblue indnocoll)
               "brazempl/tex/v1/summ/count`yr'`var'.dta", "brazempl/tex/v1/summ/count`yr'`var'_tbl.tex" (where `yr' in 90 97 and `var' in indfem indblue indnocoll)
               "brazempl/tex/v1/wage/wage`yr'sec`sec'_tbl.dta" (where `yr' in 90 97 and `sec' in 4 5 2 1)
               "brazempl/tex/v1/corr/lnw`fe'compedusec`sec'yr`yr'_tbl.dta" (where `fe' in "plain" ""; `sec' in 1 2 4 5; `yr' in 90 97)
               "brazempl/auxil/akmt-firm-secfe.csv" 
               "brazempl/auxil/akmt-worker-plantfe.csv" 
               "brazempl/auxil/akmt-summdata.csv"
               "brazempl/auxil/fr92edu.csv" 
               "brazempl/auxil/us90edu.csv"
               "brazempl/tex/regressor-list.tex" */
    /* OUTPUT: (none)
       Tables: "brazempl/tex/v1/tables/prfl`type'_tbl.dta", "brazempl/tex/v1/tables/prfl`type'.tex" (where `type' in comp brsec)
               "brazempl/tex/v1/tables/prflbrsec_pap_tbl.dta", "brazempl/tex/v1/tables/prflbrsec_pap.tex"
               "brazempl/tex/v1/tables/prfl`type'plain_tbl.dta", "brazempl/tex/v1/tables/prfl`type'plain.tex" (where `type' in comp brsec)
               "brazempl/tex/v1/tables/braz`yr'`regname'_tbl.dta", "brazempl/tex/v1/tables/braz`yr'`regname'.tex" (where `yr' in 90 97 and `regname' in indgrad edu noedu)
               "brazempl/tex/v1/tables/braz`regname'_tbl.dta", "brazempl/tex/v1/tables/braz`regname'.tex" (where `regname' in indgrad edu noedu)
               "brazempl/tex/v1/tables/brazplain`yr'`regname'_tbl.dta", "brazempl/tex/v1/tables/brazplain`yr'`regname'.tex" (where `yr' in 90 97 and `regname' in indgrad edu noedu)
               "brazempl/tex/v1/tables/brazplain`regname'_tbl.dta", "brazempl/tex/v1/tables/brazplain`regname'.tex" (where `regname' in indgrad edu noedu)
               "brazempl/tex/v1/tables/brazplaincomp_tbl.dta", "brazempl/tex/v1/tables/brazplaincomp.tex"
               "brazempl/tex/v1/tables/prflplaincomp_tbl.dta", "brazempl/tex/v1/tables/prflplaincomp.tex"
               "brazempl/tex/v1/tables/firmperf_tbl.dta", "brazempl/tex/v1/tables/firmperf.tex"
               "brazempl/tex/v1/tables/firminp_tbl.dta", "brazempl/tex/v1/tables/firminp.tex"
               "brazempl/tex/v1/tables/firmcomp`yr'_tbl.dta", "brazempl/tex/v1/tables/firmcomp`yr'.tex" (where `yr' in 90 97 or empty)
               "brazempl/tex/v1/tables/compest_tbl.dta", "brazempl/tex/v1/tables/compest.tex"
               "brazempl/tex/v1/tables/compsumm_tbl.dta", "brazempl/tex/v1/tables/compsumm.tex"
               "brazempl/tex/v1/tables/summtex`yr'_tbl.dta", "brazempl/tex/v1/tables/summtex`yr'.tex" (where `yr' in 90 97) 
               "brazempl/tex/v1/tables/summtex`yr'pt`pt'_tbl.dta", "brazempl/tex/v1/tables/summtex`yr'pt`pt'.tex" (where `yr' in 90 97 and `pt' in 1 2) 
               "brazempl/tex/v1/tables/summtex9097_tbl.dta", "brazempl/tex/v1/tables/summtex9097.tex"
               "brazempl/tex/v1/tables/lnwmean_tbl.dta", "brazempl/tex/v1/tables/lnwmean.tex"
               "brazempl/tex/v1/tables/count_tbl.dta", "brazempl/tex/v1/tables/count.tex" 
               "brazempl/tex/v1/tables/shares_tbl.dta", "brazempl/tex/v1/tables/shares.tex"
               "brazempl/tex/v1/tables/lnwmeanshr_tbl.dta", "brazempl/tex/v1/tables/lnwmeanshr.tex" 
               "brazempl/tex/v1/tables/shares`yr'_tbl.dta", "brazempl/tex/v1/tables/shares`yr'.tex" (where `yr' in 90 97) 
               "brazempl/tex/v1/tables/shares_tbl.dta", "brazempl/tex/v1/tables/shares.tex" 
               "brazempl/tex/v1/tables/lnwcomp`yr'manuf_tbl.dta", "brazempl/tex/v1/tables/lnwcomp`yr'manuf.tex" (where `yr' in 90 97) 
               "brazempl/tex/v1/tables/lnwcomp`yr'sqcfdev_tbl.dta", "brazempl/tex/v1/tables/lnwcomp`yr'sqcfdev.tex" (where `yr' in 90 97) 
               "brazempl/tex/v1/tables/lnwcomp9097manuf_tbl.dta", "brazempl/tex/v1/tables/lnwcomp9097manuf.tex"
               "brazempl/tex/v1/tables/lnwcomp9097manuf_pc_tbl.dta", "brazempl/tex/v1/tables/lnwcomp9097manuf_pc.tex" */

* do "brazempl/%stata/%3tables-graphs/tables-allyrs.do"
    /* SUMMARY STATISTICS AND CROSS-SECTION TIME-SERIES VARIATION AT MACRO LEVEL */
    /* INPUT:  "rais-sp/rais/cntfemtot.dta"
               "rais-sp/rais/cntmasctot.dta"
               "brazempl/tex/v1/corr/corr`yr'sec`sec'`regname'_tbl.dta" (`yr' in 90 97; `sec' in 1 2 4 5; `regname' in edu noedu)
               "brazempl/tex/v1/sec/wrkrfrmfe_pia_tbl.dta"
               "brazempl/tex/v1/sec/wrkrfrmfe_rais_tbl.dta"
               "brazempl/tex/regressor-list.tex" */
    /* OUTPUT: (none)
       Tables: "brazempl/tex/v1/tables/cntfemtot_tbl.dta", "brazempl/tex/v1/tables/cntfemtot.tex"
               "brazempl/tex/v1/tables/cntmasctot_tbl.dta", "brazempl/tex/v1/tables/cntmasctot.tex" 
               "brazempl/tex/v1/tables/wrkrfrmfe_tbl.dta", "brazempl/tex/v1/tables/wrkrfrmfe.tex"
               "brazempl/tex/v1/tables/fe`stat'`regname'_tbl.dta", "brazempl/tex/v1/tables/fe`stat'`regname'.tex" (`stat' in mean sdev; `regname' in edu noedu) */


* PNAD DATA
*----------

* do "brazempl/%stata/%5pnad/pnad90-97.do"
    /* LOAD PNAD DATA */
    /* INPUT:  "brazempl/pnad/pnad`yr'com.dta" (where `yr' in 90 and 97) */
    /* OUTPUT: "brazempl/pnad/pnad`yr'.dta" (where `yr' in 90 and 97) */

* do "brazempl/%stata/%5pnad/prep-pnad.do"
    /* PREPARE PNAD DATA */
    /* INPUT:  "brazempl/pnad/pnad`yr'.dta" (where `yr' in 90 and 97) 
               "brazaux/auxil/__brl_d.csv" */
    /* OUTPUT: "brazempl/pnad/use-pnad-`yr'.dta" (where `yr' in 90 and 97) */

* do "brazempl/%stata/%5pnad/reg-worker-pnad.do"
    /* REPLICATION OF ANALYSIS FOR PNAD */
    /* INPUT:  "brazempl/pnad/use-pnad-`yr'.dta" (where `yr' in 90 and 97) */
    /* OUTPUT: 
       Tables: "brazempl/tex/pnad/corr/corr`infrm'`yr'sec4`var'_tbl.dta", "brazempl/tex/pnad/corr/corr`infrm'`yr'sec4`var'.tex" (where `yr' in 90 97, `infrm' in all informl forml, `var' in indgrad edu edublu noedu) 
               "brazempl/tex/pnad/wage/wageraisyr'sec4_tbl.dta", "brazempl/tex/pnad/wage/wage`infrm'yr'sec4.tex" (where `yr' in 90 97, `infrm' in all informl forml, `var' in indgrad edu edublu noedu) 
       Logs:   "brazempl/logs/reg-worker-pnad.log" */

* do "brazempl/%stata/%5pnad/reg-worker-rais.do"
    /* COMPARABLE ESTIMATES TO PNAD USING RAIS */
    /* INPUT:  "brazempl/use-brazempl-`yr'.dta" (where `yr' in 90 and 97) */
    /* OUTPUT: 
       Tables: "brazempl/tex/pnad/corr/corrrais`yr'sec`sec'`var'_tbl.dta", "brazempl/tex/pnad/corr/corrrais`yr'sec`sec'`var'.tex" (where `yr' in 90 97, `var' in indgrad edu edublu noedu) 
               "brazempl/tex/pnad/wage/wageraisyr'sec4_tbl.dta", "brazempl/tex/pnad/wage/wageraisyr'sec4.tex" (where `yr' in 90 97, `var' in indgrad edu edublu noedu) 
       Logs:   "brazempl/logs/reg-worker-rais.log" */

* do "brazempl/%stata/%5pnad/tables-pnad-naercio.do"
    /* COMPARATIVE STATISTICS RAIS AND PNAD */
    /* INPUT:  "brazempl/tex/v1/tables/lnwmeanshr_tbl.dta"
               "brazempl/tex/v1/summ/sdv`yr'`var'_tbl.dta" (where `yr' in 90 97 and `var' in indfem indnocoll indblue)
               "brazempl/tex/v1/summ/summtex`yr'sec4_tbl.dta" (where `yr' in 90 97)
               "brazempl/auxil/pnad-`column'.csv" (where column in emprego formal informal)
               "brazempl/tex/regressor-list.tex" */
    /* OUTPUT: (none)
       Tables: "brazempl/tex/v1/tables/infpnad_tbl.dta", "brazempl/tex/v1/tables/infpnad.tex"
               "brazempl/tex/v1/tables/emplpnad_tbl.dta", "brazempl/tex/v1/tables/emplpnad.tex"              
               "brazempl/tex/v1/tables/lnwmeanshr_pnad_tbl.dta", "brazempl/tex/v1/tables/lnwmeanshr_pnad.tex"
               "brazempl/tex/v1/tables/lnwagepnad1_tbl.dta", "brazempl/tex/v1/tables/lnwagepnad1.tex"
               "brazempl/tex/v1/tables/lnwagepnad2_tbl.dta", "brazempl/tex/v1/tables/lnwagepnad2.tex"
               "brazempl/tex/v1/tables/secpnad_tbl.dta", "brazempl/tex/v1/tables/secpnad.tex"
               "brazempl/tex/v1/tables/forminform_tbl.dta", "brazempl/tex/v1/tables/forminform.tex"
               "brazempl/tex/v1/tables/premiapnad_tbl.dta", "brazempl/tex/v1/tables/premiapnad.tex" */

* do "brazempl/%stata/%5pnad/summpnad.do"
    /* SUMMARIZE PNAD DATA BY YEAR */
    /* INPUT:  "brazempl/pnad/use-pnad-`yr'.dta" */
    /* OUTPUT: (none)
       Tables: "brazempl/tex/pnad/summ/summtex`yr'sec4`infrm'_tbl.dta", "brazempl/tex/pnad/summ/summtex`yr'sec4`infrm'.tex" (where `yr' in 90 through 98)
               "brazempl/tex/pnad/summ/lnwmean`yr'`var'_`infrm'.dta", "brazempl/tex/pnad/summ/lnwmean`yr'`var'_`infrm'_tbl.tex" (where `yr' in 90 97 and `var' in indfem indblue indnocoll)
               "brazempl/tex/pnad/summ/sdv`yr'`var'_`infrm'.dta", "brazempl/tex/pnad/summ/sdv`yr'`var'_`infrm'_tbl.tex" (where `yr' in 90 97 and `var' in indfem indblue indnocoll)
               "brazempl/tex/pnad/summ/count`yr'`var'_`infrm'.dta", "brazempl/tex/pnad/summ/count`yr'`var'_`infrm'_tbl.tex" (where `yr' in 90 97 and `var' in indfem indblue indnocoll) */

* do "brazempl/%stata/%5pnad/edu-occu-sex-pnad.do"
    /* EDUCATION, OCCUPATION, GENDER TABLES AND GRAPHS */
    /* INPUT:  "brazempl/tex/pnad/wage/wage`infrm'`yr'sec4_tbl.dta" (where `yr' in 90 through 98) 
               "brazempl/tex/pnad/corr/corr`infrm'`yr'sec4_tbl.dta" (where `yr' in 90 through 98) 
               "brazempl/tex/pnad/summ/summtex`yr'sec4`infrm'_tbl.dta" (where `yr' in 90 through 98) */
    /* OUTPUT: (none)
       Tables: "brazempl/tex/pnad/tables/prflbrsec`profile'_`infrm'_tbl.dta", "brazempl/tex/pnad/prflbrsec`profile'_`infrm'.tex" (where `profile' in edu occblu sec) */

* do "brazempl/%stata/%5pnad/tables-pnad-manuf.do"
    /* COMPARATIVE STATISTICS RAIS AND PNAD */
    /* INPUT:  "brazempl/tex/pnad/summ/summtex`yr'sec4_tbl.dta" (`infrm' in forml informl)
               "brazempl/tex/pnad/summ/summtex`yr'sec4`infrm'_tbl.dta" (where `yr' in 90 97, `infrm' in forml informl)
               "brazempl/tex/pnad/wage/wage`infrm'`yr'sec`sec'_tbl.dta"
               "brazempl/tex/regressor-list.tex" */
    /* OUTPUT: (none)
       Tables: "brazempl/tex/pnad/tables/lnwmeansdv_pnad_tbl.dta", "brazempl/tex/pnad/tables/lnwmeansdv_pnad.tex", "brazempl/tex/pnad/tables/lnwmeansdv_pnad_rowlbl.dta"
               "brazempl/tex/pnad/tables/braz`yr'`regname'_tbl.dta", "brazempl/tex/pnad/tables/braz`yr'`regname'.tex", "brazempl/tex/pnad/tables/braz`yr'`regname'_rowlbl.dta"  (where `yr' in 90 97, `regname' in edu edublu)
               "brazempl/tex/pnad/tables/prflinfrm`blue'_tbl.dta", "brazempl/tex/pnad/tables/prflinfrm`blue'.tex", "brazempl/tex/pnad/tables/prflinfrm`blue'_rowlbl.dta" (where `blue' in "" blu)
               "brazempl/tex/pnad/tables/summtex`yr'_tbl.dta", "brazempl/tex/pnad/tables/summtex`yr'.tex", "brazempl/tex/pnad/tables/summtex`yr'_rowlbl.dta" (where `yr' in "" 90 97) */


* SELECTIVITY PROCEDURES
*-----------------------

* do "brazempl/%stata/%6heckman/heckman-pnad.do"
    /* HECKMAN SELECTION AND WAGE REGRESSIONS ON PNAD SAMPLE */
    /* INPUT:  "brazempl/pnad/use-pnad-`yr'.dta" (where `yr' in 90 and 97) */
    /* OUTPUT: 
       Tables: "brazempl/tex/pnad/corr/corrheckman`yr'sec4`var'_tbl.dta", "brazempl/tex/pnad/corr/corrheckman`yr'sec4`var'.tex" (where `yr' in 90 97, `var' in indgrad edu edublu noedu)
               "brazempl/tex/pnad/wage/wageheckman`yr'sec4_tbl.dta", "brazempl/tex/pnad/wage/wageheckman`yr'sec4.tex" (where `yr' in 90 97)
       Logs:   "brazempl/logs/heckman-pnad.log" */

* do "brazempl/%stata/%6heckman/heckman-rais.do"
    /* HECKMAN SELECTION REGRESSIONS ON RAIS SAMPLE (OUT-OF-SAMPLE PREDICTION) */
    /* INPUT:  "brazempl/pnad/use-pnad-`yr'.dta" (where `yr' in 90 and 97) 
               "brazempl/use-brazempl-`yr'.dta" (where `yr' in 90 and 97) */
    /* OUTPUT: 
       Tables: "brazempl/tex/heckman/corr/corr`regr'`yr'sec4`data'_tbl.dta", "brazempl/tex/pnad/corr/corr`regr'`yr'sec4`data'.tex" (where `yr' in 90 97, `regr' in pnad reg xtreg, `data' in blu edu)
               "brazempl/tex/heckman/wage/wageheckman`yr'sec4_tbl.dta", "brazempl/tex/pnad/wage/wageheckman`yr'sec4.tex" (where `yr' in 90 97)
       Logs:   "brazempl/logs/heckman-rais.log" */

* do "brazempl/%stata/%6heckman/edu-occu-sex.do"
    /* EDUCATION, OCCUPATION, GENDER TABLES AND GRAPHS */
    /* INPUT:  "brazempl/tex/heckman/wage/wageheckman`yr'sec`sec'_tbl.dta" (where `yr' in 90 through 98, `sec' in 4) 
               "brazempl/tex/heckman/corr/corr`yr'sec`sec'_tbl.dta" (where `yr' in 90 through 98, `sec' in 4) 
               "brazempl/tex/heckman/summ/summtex`yr'sec`sec'_tbl.dta" (where `yr' in 90 through 98, `sec' in 4) */
    /* OUTPUT: (none)
       Tables: "brazempl/tex/heckman/tables/prflcomp`profile'_tbl.dta", "brazempl/tex/heckman/prflcomp`profile'.tex" (where `profile' in edu occu sex)
               "brazempl/tex/heckman/tables/prflbrsec`profile'_tbl.dta", "brazempl/tex/heckman/prflbrsec`profile'.tex" (where `profile' in edu occu sec) */

* do "brazempl/repl-semip/gerfin/replicate.do"
    /* REPLICATION OF MICHAEL GERFIN (Journal of Applied Econometrics 1996, 321-339) */
    /* INPUT:  "brazempl/repl-semip/gerfin/swiss.asc" */
    /* OUTPUT: 
       Logs:   "brazempl/repl-semip/gerfin/repl-gerfin.log" */

* do "brazempl/%stata/%6heckman/kleinspady-pnad.do"
    /* KLEIN-SPADY SELECTION REGRESSIONS ON PNAD SAMPLE */
    /* INPUT:  "brazempl/pnad/use-pnad-`yr'.dta" (where `yr' in 90 and 97) */
    /* OUTPUT: 
       Tables: "brazempl/tex/pnad/kleinspady/kleinspady`yr'sec4_tbl.dta", "brazempl/tex/pnad/kleinspady/kleinspady`yr'sec4.tex" (where `yr' in 90 97)
       Logs:   "brazempl/logs/kleinspady-pnad.log" */

* do "brazempl/%stata/%6heckman/nonparam-pnad-crossval.do"
    /* NONPARAMETRIC SELECTION AND WAGE REGRESSIONS ON PNAD SAMPLE */
    /* INPUT:  "brazempl/pnad/use-pnad-`yr'.dta" (where `yr' in 90 and 97) */
    /* OUTPUT: 
       Tables: "brazempl/tex/pnad/nonparam/crossval_tbl.dta", "brazempl/tex/pnad/nonparam/crossval.tex"
       Logs:   "brazempl/logs/nonparam-pnad-crossval.log" */

* do "brazempl/%stata/%6heckman/nonparam-pnad-rais.do"
    /* NONPARAMETRIC SELECTION AND WAGE REGRESSIONS ON PNAD SAMPLE */
    /* INPUT:  "brazempl/pnad/use-pnad-`yr'.dta" (where `yr' in 90 and 97) */
    /* OUTPUT: 
       Tables: "brazempl/tex/pnad/nonparam/wage`yr'sec4_tbl.dta", "brazempl/tex/pnad/nonparam/wage`yr'sec4.tex" (where `yr' in 90 97)
               "brazempl/tex/pnad/nonparam/corr`yr'sec4nonparam_tbl.dta", "brazempl/tex/pnad/nonparam/corr`yr'sec4nonparam.tex" (where `yr' in 90 97)
       Logs:   "brazempl/logs/nonparam-pnad-rais.log" */

* do "brazempl/%stata/%6heckman/edu-occu-sex-nonparam.do"
    /* EDUCATION, OCCUPATION, GENDER TABLES AND GRAPHS */
    /* INPUT:  "brazempl/tex/nonparam/wagenonparam`yr'sec`sec'_tbl.dta" (where `yr' in 90 through 98, `sec' in 4) 
               "brazempl/tex/nonparam/corr`yr'sec`sec'_tbl.dta" (where `yr' in 90 through 98, `sec' in 4) 
               "brazempl/tex/nonparam/summtex`yr'sec`sec'_tbl.dta" (where `yr' in 90 through 98, `sec' in 4) */
    /* OUTPUT: (none)
       Tables: "brazempl/tex/nonparam/prflcomp`profile'_tbl.dta", "brazempl/tex/nonparam/prflcomp`profile'.tex" (where `profile' in edu occu sex)
               "brazempl/tex/nonparam/prflbrsec`profile'_tbl.dta", "brazempl/tex/nonparam/prflbrsec`profile'.tex" (where `profile' in edu occu sec) */

* do "brazempl/%stata/%6heckman/tables-heckman-90-97.do"
    /* HECKMAN TEX TABLES */
    /* INPUT:  "brazempl/tex/heckman/wage/wageheckman`yr'sec4_tbl.dta" (where `yr' in 90 97)
               "brazempl/tex/pnad/wage/wage`infrm'`yr'sec`sec'_tbl.dta" (where `yr' in 90 97)
               "brazempl/tex/v1/wage/wage`yr'sec4_tbl.dta" (where `yr' in 90 97)
               "brazempl/tex/regressor-list.tex" */
    /* OUTPUT: (none)
       Tables: "brazempl/tex/heckman/tables/selection.tex", "brazempl/tex/heckman/tables/selection_tbl.dta", "brazempl/tex/heckman/tables/selection_rowlbl.dta"
               "brazempl/tex/heckman/tables/pnadselcomp.tex", "brazempl/tex/heckman/tables/pnadselcomp_tbl.dta", "brazempl/tex/heckman/tables/pnadselcomp_rowlbl.dta"
               "brazempl/tex/heckman/tables/pnadraisselblu.tex", "brazempl/tex/heckman/tables/pnadraisselblu_tbl.dta", "brazempl/tex/heckman/tables/pnadraisselblu_rowlbl.dta"
               "brazempl/tex/heckman/tables/raisseledu.tex", "brazempl/tex/heckman/tables/raisseledu_tbl.dta", "brazempl/tex/heckman/tables/raisseledu_rowlbl.dta"
               "brazempl/tex/heckman/tables/raisselcomp.tex", "brazempl/tex/heckman/tables/raisselcomp_tbl.dta", "brazempl/tex/heckman/tables/raisselcomp_rowlbl.dta"
               "brazempl/tex/heckman/tables/prflselcomp.tex", "brazempl/tex/heckman/tables/prflselcomp_tbl.dta", "brazempl/tex/heckman/tables/prflselcomp_rowlbl.dta" */

* do "brazempl/%stata/%6heckman/tables-nonparam-90-97.do"
    /* HECKMAN TEX TABLES */
    /* INPUT:  "brazempl/tex/nonparam/wage`yr'sec4_tbl.dta" (where `yr' in 90 97)
               "brazempl/tex/pnad/wage/wage`infrm'`yr'sec`sec'_tbl.dta" (where `yr' in 90 97)
               "brazempl/tex/v1/wage/wage`yr'sec4_tbl.dta" (where `yr' in 90 97)
               "brazempl/tex/regressor-list.tex" */
    /* OUTPUT: (none)
       Tables: "brazempl/tex/nonparam/tables/selection.tex", "brazempl/tex/nonparam/tables/selection_tbl.dta", "brazempl/tex/nonparam/tables/selection_rowlbl.dta"
               "brazempl/tex/nonparam/tables/pnadselcomp.tex", "brazempl/tex/nonparam/tables/pnadselcomp_tbl.dta", "brazempl/tex/nonparam/tables/pnadselcomp_rowlbl.dta"
               "brazempl/tex/nonparam/tables/pnadraisselblu.tex", "brazempl/tex/nonparam/tables/pnadraisselblu_tbl.dta", "brazempl/tex/nonparam/tables/pnadraisselblu_rowlbl.dta"
               "brazempl/tex/nonparam/tables/raisseledu.tex", "brazempl/tex/nonparam/tables/raisseledu_tbl.dta", "brazempl/tex/nonparam/tables/raisseledu_rowlbl.dta"
               "brazempl/tex/nonparam/tables/raisselcomp.tex", "brazempl/tex/nonparam/tables/raisselcomp_tbl.dta", "brazempl/tex/nonparam/tables/raisselcomp_rowlbl.dta"
               "brazempl/tex/nonparam/tables/prflselcomp.tex", "brazempl/tex/nonparam/tables/prflselcomp_tbl.dta", "brazempl/tex/nonparam/tables/prflselcomp_rowlbl.dta" */


* CONFIDENTIAL DATA
*------------------

* do "brazempl/%stata/%4empl-effects-pia/repl-Xpia-data.do"
    /* CREATE (confidential) FIRM-LEVEL DATA SET FOR ESTIMATION */
    /* INPUT:  "brazdspl/Xpia/firms-86-98.dta" (from brazaux:pia-random-agg:prep-data.do)
               "brazempl/data/firm-skills-`yr'.dta" (where `yr' in 90, 92 through 98)
               "brazempl/est/v1/firmpred-edu-sec`sec'-`yr'.dta" (where `sec' in 1 2 4 5; `yr' in 90, 92 through 98) 
               "brazdspl/pia/prodcoeff-brazprod.dta" (from brazaux:pia-random-agg:prep-tfp.do)
               "brazaux/auxil/niv50.do" */
    /* OUTPUT: "brazempl/Xpia/use-firms-`yr'.dta" (where `yr' in 90, 92 through 98)
         Logs: "brazempl/logs/repl-Xpia-data.log" (where `run' counts repetitions of the procedure) */ 

* do "brazempl/%stata/%4empl-effects-pia/xtreg-Xfirm-secfe.do"
    /* ESTIMATE (confidential) FIRM-LEVEL MODEL WITH SECTOR-LEVEL FIXED EFFECTS (at IBGE) */
    /* INPUT:  "brazempl/Xpia/use-firms-`yr'.dta" (where `yr' in 90, 92 through 98) */
    /* OUTPUT: (none)
       Tables: "brazempl/tex/v1/sec/Xfirmpia_tbl.dta", "brazempl/tex/v1/sec/firmpia.tex" 
               "brazempl/tex/v1/sec/Xfirm`yr'pia_tbl.dta", "brazempl/tex/v1/sec/firm`yr'pia.tex" (where `yr' in 90, 92 through 98) */
    /*   Logs: "brazempl/logs/xtreg-Xfirm-secfe.log" */ 

* do "brazempl/%stata/%4empl-effects-pia/Xtables-90-97.do"
    /* COMPARISONS 1990 and 1997; COMPARISONS BETWEEN BRAZIL, FRANCE, US */
    /* INPUT:  "brazempl/tex/v1/sec/Xfirm`yr'pia_tbl.dta"
               "brazempl/auxil/akmt-firm-secfe.csv" 
               "brazempl/tex/regressor-list.tex" */
    /* OUTPUT: (none)
       Tables: "brazempl/tex/v1/tables/Xfirmperf_tbl.dta", "brazempl/tex/v1/tables/Xfirmperf.tex"
               "brazempl/tex/v1/tables/Xfirminp_tbl.dta", "brazempl/tex/v1/tables/Xfirminp.tex"
               "brazempl/tex/v1/tables/Xfirmcomp`yr'_tbl.dta", "brazempl/tex/v1/tables/Xfirmcomp`yr'.tex" (where `yr' in 90 97 or empty) */
